###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file ii.xml
# The source file version number was 1.5, generated on
# 2007/11/28 00:17:37.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ii;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

{
    my $am_pm_abbreviated = [ "ꎸꄑ", "ꁯꋒ" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_long = "yyyy\ MMMM\ d";
    sub date_format_long { return $date_format_long }
}

{
    my $day_format_abbreviated = [ "ꆏꋍ", "ꆏꑍ", "ꆏꌕ", "ꆏꇖ", "ꆏꉬ", "ꆏꃘ", "ꆏꑍ" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "ꆏꊂꋍ", "ꆏꊂꑍ", "ꆏꊂꌕ", "ꆏꊂꇖ", "ꆏꊂꉬ", "ꆏꊂꃘ", "ꑭꆏꑍ" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "ꋍ", "ꑍ", "ꌕ", "ꇖ", "ꉬ", "ꃘ", "ꆏ" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "ꃅꋊꂿ", "ꃅꋊꊂ" ];
    sub era_abbreviated { return $era_abbreviated }
}

sub era_narrow { $_[0]->era_abbreviated() }

{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "ꋍꆪ", "ꑍꆪ", "ꌕꆪ", "ꇖꆪ", "ꉬꆪ", "ꃘꆪ", "ꏃꆪ", "ꉆꆪ", "ꈬꆪ", "ꊰꆪ", "ꊰꊪꆪ", "ꊰꑋꆪ" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "ꃅꑌ", "ꃅꎸ", "ꃅꍵ", "ꃅꋆ" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}

sub quarter_format_narrow { $_[0]->quarter_stand_alone_narrow() }

{
    my $quarter_format_wide = [ "ꃅꑌ", "ꃅꎸ", "ꃅꍵ", "ꃅꋆ" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_narrow = [ "1", "2", "3", "4" ];
    sub quarter_stand_alone_narrow { return $quarter_stand_alone_narrow }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::ii

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'ii' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Sichuan Yi.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  ꆏꊂꋍ
  ꆏꊂꑍ
  ꆏꊂꌕ
  ꆏꊂꇖ
  ꆏꊂꉬ
  ꆏꊂꃘ
  ꑭꆏꑍ

=head3 Abbreviated (format)

  ꆏꋍ
  ꆏꑍ
  ꆏꌕ
  ꆏꇖ
  ꆏꉬ
  ꆏꃘ
  ꆏꑍ

=head3 Narrow (format)

  ꋍ
  ꑍ
  ꌕ
  ꇖ
  ꉬ
  ꃘ
  ꆏ

=head3 Wide (stand-alone)

  ꆏꊂꋍ
  ꆏꊂꑍ
  ꆏꊂꌕ
  ꆏꊂꇖ
  ꆏꊂꉬ
  ꆏꊂꃘ
  ꑭꆏꑍ

=head3 Abbreviated (stand-alone)

  ꆏꋍ
  ꆏꑍ
  ꆏꌕ
  ꆏꇖ
  ꆏꉬ
  ꆏꃘ
  ꆏꑍ

=head3 Narrow (stand-alone)

  ꋍ
  ꑍ
  ꌕ
  ꇖ
  ꉬ
  ꃘ
  ꆏ

=head2 Months

=head3 Wide (format)

  ꋍꆪ
  ꑍꆪ
  ꌕꆪ
  ꇖꆪ
  ꉬꆪ
  ꃘꆪ
  ꏃꆪ
  ꉆꆪ
  ꈬꆪ
  ꊰꆪ
  ꊰꊪꆪ
  ꊰꑋꆪ

=head3 Abbreviated (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  ꋍꆪ
  ꑍꆪ
  ꌕꆪ
  ꇖꆪ
  ꉬꆪ
  ꃘꆪ
  ꏃꆪ
  ꉆꆪ
  ꈬꆪ
  ꊰꆪ
  ꊰꊪꆪ
  ꊰꑋꆪ

=head3 Abbreviated (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  ꃅꑌ
  ꃅꎸ
  ꃅꍵ
  ꃅꋆ

=head3 Abbreviated (format)

  ꃅꑌ
  ꃅꎸ
  ꃅꍵ
  ꃅꋆ

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  ꃅꑌ
  ꃅꎸ
  ꃅꍵ
  ꃅꋆ

=head3 Abbreviated (stand-alone)

  ꃅꑌ
  ꃅꎸ
  ꃅꍵ
  ꃅꋆ

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  ꃅꋊꂿ
  ꃅꋊꊂ

=head3 Narrow

  ꃅꋊꂿ
  ꃅꋊꊂ

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = ꆏꊂꑍ, 2008 ꑍꆪ 05
   1995-12-22T09:05:02 = ꆏꊂꉬ, 1995 ꊰꑋꆪ 22
  -0010-12-22T23:05:02 = ꆏꊂꃘ, -010 ꊰꑋꆪ 22

=head3 Long

   2008-02-05T12:30:30 = 2008 ꑍꆪ 5
   1995-12-22T09:05:02 = 1995 ꊰꑋꆪ 22
  -0010-12-22T23:05:02 = -010 ꊰꑋꆪ 22

=head3 Medium

   2008-02-05T12:30:30 = 2008 2 5
   1995-12-22T09:05:02 = 1995 12 22
  -0010-12-22T23:05:02 = -010 12 22

=head3 Short

   2008-02-05T12:30:30 = 2008-02-05
   1995-12-22T09:05:02 = 1995-12-22
  -0010-12-22T23:05:02 = -010-12-22

=head3 Default

   2008-02-05T12:30:30 = 2008 2 5
   1995-12-22T09:05:02 = 1995 12 22
  -0010-12-22T23:05:02 = -010 12 22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = ꆏꊂꑍ, 2008 ꑍꆪ 05 12:30:30 UTC
   1995-12-22T09:05:02 = ꆏꊂꉬ, 1995 ꊰꑋꆪ 22 09:05:02 UTC
  -0010-12-22T23:05:02 = ꆏꊂꃘ, -010 ꊰꑋꆪ 22 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008 ꑍꆪ 5 12:30:30 UTC
   1995-12-22T09:05:02 = 1995 ꊰꑋꆪ 22 09:05:02 UTC
  -0010-12-22T23:05:02 = -010 ꊰꑋꆪ 22 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008 2 5 12:30:30
   1995-12-22T09:05:02 = 1995 12 22 09:05:02
  -0010-12-22T23:05:02 = -010 12 22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 2008-02-05 12:30
   1995-12-22T09:05:02 = 1995-12-22 09:05
  -0010-12-22T23:05:02 = -010-12-22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008 2 5 12:30:30
   1995-12-22T09:05:02 = 1995 12 22 09:05:02
  -0010-12-22T23:05:02 = -010 12 22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = ꆏꑍ 5
   1995-12-22T09:05:02 = ꆏꉬ 22
  -0010-12-22T23:05:02 = ꆏꃘ 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = ꆏꑍ 2 5
   1995-12-22T09:05:02 = ꆏꉬ 12 22
  -0010-12-22T23:05:02 = ꆏꃘ 12 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = ꑍꆪ 5
   1995-12-22T09:05:02 = ꊰꑋꆪ 22
  -0010-12-22T23:05:02 = ꊰꑋꆪ 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 2
   1995-12-22T09:05:02 = 95 12
  -0010-12-22T23:05:02 = 10 12

=head3 yyQ (yy Q)

   2008-02-05T12:30:30 = 8 1
   1995-12-22T09:05:02 = 95 4
  -0010-12-22T23:05:02 = 10 4

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

ꆏꊂꋍ


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
