###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file fa_AF.xml
# The source file version number was 1.55, generated on
# 2007/07/19 22:31:39.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fa_AF;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::fa';

{
    my $first_day_of_week = 6;
    sub first_day_of_week { return $first_day_of_week }
}


sub month_format_abbreviated { $_[0]->month_format_wide() }


sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "جنوری", "فبروری", "مارچ", "اپریل", "می", "جون", "جولای", "اگست", "سپتمبر", "اکتوبر", "نومبر", "دسمبر" ];
    sub month_format_wide { return $month_format_wide }
}
{
    my $month_stand_alone_narrow = [ "ج", "ف", "م", "ا", "م", "ج", "ج", "ا", "س", "ا", "ن", "د" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::fa_AF

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'fa_AF' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Persian Afghanistan.

=head1 DATA

This locale inherits from the L<DateTime::Locale::fa> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  دوشنبه
  سه‌شنبه
  چهارشنبه
  پنجشنبه
  جمعه
  شنبه
  یکشنبه

=head3 Abbreviated (format)

  دوشنبه
  سه‌شنبه
  چهارشنبه
  پنجشنبه
  جمعه
  شنبه
  یکشنبه

=head3 Narrow (format)

  د
  س
  چ
  پ
  ج
  ش
  ی

=head3 Wide (stand-alone)

  دوشنبه
  سه‌شنبه
  چهارشنبه
  پنجشنبه
  جمعه
  شنبه
  یکشنبه

=head3 Abbreviated (stand-alone)

  دوشنبه
  سه‌شنبه
  چهارشنبه
  پنجشنبه
  جمعه
  شنبه
  یکشنبه

=head3 Narrow (stand-alone)

  د
  س
  چ
  پ
  ج
  ش
  ی

=head2 Months

=head3 Wide (format)

  جنوری
  فبروری
  مارچ
  اپریل
  می
  جون
  جولای
  اگست
  سپتمبر
  اکتوبر
  نومبر
  دسمبر

=head3 Abbreviated (format)

  جنوری
  فبروری
  مارچ
  اپریل
  می
  جون
  جولای
  اگست
  سپتمبر
  اکتوبر
  نومبر
  دسمبر

=head3 Narrow (format)

  ج
  ف
  م
  ا
  م
  ج
  ج
  ا
  س
  ا
  ن
  د

=head3 Wide (stand-alone)

  جنوری
  فبروری
  مارچ
  اپریل
  می
  جون
  جولای
  اگست
  سپتمبر
  اکتوبر
  نومبر
  دسمبر

=head3 Abbreviated (stand-alone)

  ژانویه
  فوریه
  مارس
  آوریل
  مه
  ژوئن
  ژوئیه
  اوت
  سپتامبر
  اکتبر
  نوامبر
  دسامبر

=head3 Narrow (stand-alone)

  ج
  ف
  م
  ا
  م
  ج
  ج
  ا
  س
  ا
  ن
  د

=head2 Quarters

=head3 Wide (format)

  سه‌ماههٔ اول
  سه‌ماههٔ دوم
  سه‌ماههٔ سوم
  سه‌ماههٔ چهارم

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  سه‌ماههٔ اول
  سه‌ماههٔ دوم
  سه‌ماههٔ سوم
  سه‌ماههٔ چهارم

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  قبل از میلاد
  میلادی

=head3 Abbreviated

  ق.م.
  م.

=head3 Narrow

  ق.م.
  م.

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = سه‌شنبه 5 فبروری 2008 میلادی
   1995-12-22T09:05:02 = جمعه 22 دسمبر 1995 میلادی
  -0010-12-22T23:05:02 = شنبه 22 دسمبر -010 قبل از میلاد

=head3 Long

   2008-02-05T12:30:30 = 5 فبروری 2008
   1995-12-22T09:05:02 = 22 دسمبر 1995
  -0010-12-22T23:05:02 = 22 دسمبر -010

=head3 Medium

   2008-02-05T12:30:30 = 2008/2/5
   1995-12-22T09:05:02 = 1995/12/22
  -0010-12-22T23:05:02 = -010/12/22

=head3 Short

   2008-02-05T12:30:30 = 8/2/5
   1995-12-22T09:05:02 = 95/12/22
  -0010-12-22T23:05:02 = 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 5 فبروری 2008
   1995-12-22T09:05:02 = 22 دسمبر 1995
  -0010-12-22T23:05:02 = 22 دسمبر -010

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 (UTC)
   1995-12-22T09:05:02 = 9:05:02 (UTC)
  -0010-12-22T23:05:02 = 23:05:02 (UTC)

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 (UTC)
   1995-12-22T09:05:02 = 9:05:02 (UTC)
  -0010-12-22T23:05:02 = 23:05:02 (UTC)

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 9:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 9:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 (UTC)، ساعت سه‌شنبه 5 فبروری 2008 میلادی
   1995-12-22T09:05:02 = 9:05:02 (UTC)، ساعت جمعه 22 دسمبر 1995 میلادی
  -0010-12-22T23:05:02 = 23:05:02 (UTC)، ساعت شنبه 22 دسمبر -010 قبل از میلاد

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 (UTC)، ساعت 5 فبروری 2008
   1995-12-22T09:05:02 = 9:05:02 (UTC)، ساعت 22 دسمبر 1995
  -0010-12-22T23:05:02 = 23:05:02 (UTC)، ساعت 22 دسمبر -010

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30، ساعت 2008/2/5
   1995-12-22T09:05:02 = 9:05:02، ساعت 1995/12/22
  -0010-12-22T23:05:02 = 23:05:02، ساعت -010/12/22

=head3 Short

   2008-02-05T12:30:30 = 12:30، ساعت 8/2/5
   1995-12-22T09:05:02 = 9:05، ساعت 95/12/22
  -0010-12-22T23:05:02 = 23:05، ساعت 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 12:30:30، ساعت 5 فبروری 2008
   1995-12-22T09:05:02 = 9:05:02، ساعت 22 دسمبر 1995
  -0010-12-22T23:05:02 = 23:05:02، ساعت 22 دسمبر -010

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = سه‌شنبه 5
   1995-12-22T09:05:02 = جمعه 22
  -0010-12-22T23:05:02 = شنبه 22

=head3 GGGGyyyyMMMMd (d MMMM yyyy GGGG)

   2008-02-05T12:30:30 = 5 فبروری 2008 میلادی
   1995-12-22T09:05:02 = 22 دسمبر 1995 میلادی
  -0010-12-22T23:05:02 = 22 دسمبر -010 قبل از میلاد

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmZ (HH:mm (Z))

   2008-02-05T12:30:30 = 12:30 (+0000)
   1995-12-22T09:05:02 = 09:05 (+0000)
  -0010-12-22T23:05:02 = 23:05 (+0000)

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = سه‌شنبه فبروری 5
   1995-12-22T09:05:02 = جمعه دسمبر 22
  -0010-12-22T23:05:02 = شنبه دسمبر 22

=head3 MMMMd (d MMMM)

   2008-02-05T12:30:30 = 5 فبروری
   1995-12-22T09:05:02 = 22 دسمبر
  -0010-12-22T23:05:02 = 22 دسمبر

=head3 Md (M/d)

   2008-02-05T12:30:30 = 2/5
   1995-12-22T09:05:02 = 12/22
  -0010-12-22T23:05:02 = 12/22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 فبروری
   1995-12-22T09:05:02 = 95 دسمبر
  -0010-12-22T23:05:02 = 10 دسمبر

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head3 yyyyM (yyyy/M)

   2008-02-05T12:30:30 = 2008/2
   1995-12-22T09:05:02 = 1995/12
  -0010-12-22T23:05:02 = -010/12

=head3 yyyyMMMM (MMMM yyyy)

   2008-02-05T12:30:30 = فبروری 2008
   1995-12-22T09:05:02 = دسمبر 1995
  -0010-12-22T23:05:02 = دسمبر -010

=head3 yyyyMMMMEEEEd (EEEE d MMMM yyyy)

   2008-02-05T12:30:30 = سه‌شنبه 5 فبروری 2008
   1995-12-22T09:05:02 = جمعه 22 دسمبر 1995
  -0010-12-22T23:05:02 = شنبه 22 دسمبر -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

شنبه


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
