###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file ln_CG.xml
# The source file version number was 1.12, generated on
# 2007/07/19 22:31:39.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ln_CG;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::ln';

{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::ln_CG

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'ln_CG' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Lingala Congo - Brazzaville.

=head1 DATA

This locale inherits from the L<DateTime::Locale::ln> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  mokɔlɔ ya libosó
  mokɔlɔ ya míbalé
  mokɔlɔ ya mísáto
  mokɔlɔ ya mínéi
  mokɔlɔ ya mítáno
  mpɔ́sɔ
  eyenga

=head3 Abbreviated (format)

  m1
  m2
  m3
  m4
  m5
  mps
  eye

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  mokɔlɔ ya libosó
  mokɔlɔ ya míbalé
  mokɔlɔ ya mísáto
  mokɔlɔ ya mínéi
  mokɔlɔ ya mítáno
  mpɔ́sɔ
  eyenga

=head3 Abbreviated (stand-alone)

  m1
  m2
  m3
  m4
  m5
  mps
  eye

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  sánzá ya yambo
  sánzá ya míbalé
  sánzá ya mísáto
  sánzá ya mínei
  sánzá ya mítáno
  sánzá ya motóbá
  sánzá ya nsambo
  sánzá ya mwambe
  sánzá ya libwa
  sánzá ya zómi
  sánzá ya zómi na mɔ̌kɔ́
  sánzá ya zómi na míbalé

=head3 Abbreviated (format)

  s1
  s2
  s3
  s4
  s5
  s6
  s7
  s8
  s9
  s10
  s11
  s12

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  sánzá ya yambo
  sánzá ya míbalé
  sánzá ya mísáto
  sánzá ya mínei
  sánzá ya mítáno
  sánzá ya motóbá
  sánzá ya nsambo
  sánzá ya mwambe
  sánzá ya libwa
  sánzá ya zómi
  sánzá ya zómi na mɔ̌kɔ́
  sánzá ya zómi na míbalé

=head3 Abbreviated (stand-alone)

  s1
  s2
  s3
  s4
  s5
  s6
  s7
  s8
  s9
  s10
  s11
  s12

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  sánzá mísáto ya yambo
  sánzá mísáto ya míbalé
  sánzá mísáto ya mísáto
  sánzá mísáto ya mínei

=head3 Abbreviated (format)

  SM1
  SM2
  SM3
  SM4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  sánzá mísáto ya yambo
  sánzá mísáto ya míbalé
  sánzá mísáto ya mísáto
  sánzá mísáto ya mínei

=head3 Abbreviated (stand-alone)

  SM1
  SM2
  SM3
  SM4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  libosó ya Y.-K.
  nsima ya Y.-K.

=head3 Abbreviated

  libosó ya Y.-K.
  nsima ya Y.-K.

=head3 Narrow

  libosó ya Y.-K.
  nsima ya Y.-K.

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = mokɔlɔ ya míbalé, 2008 sánzá ya míbalé 05
   1995-12-22T09:05:02 = mokɔlɔ ya mítáno, 1995 sánzá ya zómi na míbalé 22
  -0010-12-22T23:05:02 = mpɔ́sɔ, -010 sánzá ya zómi na míbalé 22

=head3 Long

   2008-02-05T12:30:30 = 2008 sánzá ya míbalé 5
   1995-12-22T09:05:02 = 1995 sánzá ya zómi na míbalé 22
  -0010-12-22T23:05:02 = -010 sánzá ya zómi na míbalé 22

=head3 Medium

   2008-02-05T12:30:30 = 2008 s2 5
   1995-12-22T09:05:02 = 1995 s12 22
  -0010-12-22T23:05:02 = -010 s12 22

=head3 Short

   2008-02-05T12:30:30 = 8/02/05
   1995-12-22T09:05:02 = 95/12/22
  -0010-12-22T23:05:02 = 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 2008 s2 5
   1995-12-22T09:05:02 = 1995 s12 22
  -0010-12-22T23:05:02 = -010 s12 22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = mokɔlɔ ya míbalé, 2008 sánzá ya míbalé 05 12:30:30 UTC
   1995-12-22T09:05:02 = mokɔlɔ ya mítáno, 1995 sánzá ya zómi na míbalé 22 09:05:02 UTC
  -0010-12-22T23:05:02 = mpɔ́sɔ, -010 sánzá ya zómi na míbalé 22 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008 sánzá ya míbalé 5 12:30:30 UTC
   1995-12-22T09:05:02 = 1995 sánzá ya zómi na míbalé 22 09:05:02 UTC
  -0010-12-22T23:05:02 = -010 sánzá ya zómi na míbalé 22 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008 s2 5 12:30:30
   1995-12-22T09:05:02 = 1995 s12 22 09:05:02
  -0010-12-22T23:05:02 = -010 s12 22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8/02/05 12:30
   1995-12-22T09:05:02 = 95/12/22 09:05
  -0010-12-22T23:05:02 = 10/12/22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008 s2 5 12:30:30
   1995-12-22T09:05:02 = 1995 s12 22 09:05:02
  -0010-12-22T23:05:02 = -010 s12 22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = m2 5
   1995-12-22T09:05:02 = m5 22
  -0010-12-22T23:05:02 = mps 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = m2 s2 5
   1995-12-22T09:05:02 = m5 s12 22
  -0010-12-22T23:05:02 = mps s12 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = sánzá ya míbalé 5
   1995-12-22T09:05:02 = sánzá ya zómi na míbalé 22
  -0010-12-22T23:05:02 = sánzá ya zómi na míbalé 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 s2
   1995-12-22T09:05:02 = 95 s12
  -0010-12-22T23:05:02 = 10 s12

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

mokɔlɔ ya libosó


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
