###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file sw_TZ.xml
# The source file version number was 1.48, generated on
# 2007/07/14 23:02:17.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sw_TZ;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::sw';

{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::sw_TZ

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'sw_TZ' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Swahili Tanzania.

=head1 DATA

This locale inherits from the L<DateTime::Locale::sw> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Jumatatu
  Jumanne
  Jumatano
  Alhamisi
  Ijumaa
  Jumamosi
  Jumapili

=head3 Abbreviated (format)

  Jtt
  Jnn
  Jtn
  Alh
  Iju
  Jmo
  Jpi

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  Jumatatu
  Jumanne
  Jumatano
  Alhamisi
  Ijumaa
  Jumamosi
  Jumapili

=head3 Abbreviated (stand-alone)

  Jtt
  Jnn
  Jtn
  Alh
  Iju
  Jmo
  Jpi

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  Januari
  Februari
  Machi
  Aprili
  Mei
  Juni
  Julai
  Agosti
  Septemba
  Oktoba
  Novemba
  Desemba

=head3 Abbreviated (format)

  Jan
  Feb
  Mac
  Apr
  Mei
  Jun
  Jul
  Ago
  Sep
  Okt
  Nov
  Des

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  Januari
  Februari
  Machi
  Aprili
  Mei
  Juni
  Julai
  Agosti
  Septemba
  Oktoba
  Novemba
  Desemba

=head3 Abbreviated (stand-alone)

  Jan
  Feb
  Mac
  Apr
  Mei
  Jun
  Jul
  Ago
  Sep
  Okt
  Nov
  Des

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  robo ya kwanza
  robo ya pili
  robo ya tatu
  robo ya nne

=head3 Abbreviated (format)

  R1
  R2
  R3
  R4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  robo ya kwanza
  robo ya pili
  robo ya tatu
  robo ya nne

=head3 Abbreviated (stand-alone)

  R1
  R2
  R3
  R4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Kabla ya Kristo
  Baada ya Kristo

=head3 Abbreviated

  KK
  BK

=head3 Narrow

  KK
  BK

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = Jumanne, 2008 Februari 05
   1995-12-22T09:05:02 = Ijumaa, 1995 Desemba 22
  -0010-12-22T23:05:02 = Jumamosi, -010 Desemba 22

=head3 Long

   2008-02-05T12:30:30 = 2008 Februari 5
   1995-12-22T09:05:02 = 1995 Desemba 22
  -0010-12-22T23:05:02 = -010 Desemba 22

=head3 Medium

   2008-02-05T12:30:30 = 2008 Feb 5
   1995-12-22T09:05:02 = 1995 Des 22
  -0010-12-22T23:05:02 = -010 Des 22

=head3 Short

   2008-02-05T12:30:30 = 8/02/05
   1995-12-22T09:05:02 = 95/12/22
  -0010-12-22T23:05:02 = 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 2008 Feb 5
   1995-12-22T09:05:02 = 1995 Des 22
  -0010-12-22T23:05:02 = -010 Des 22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = Jumanne, 2008 Februari 05 12:30:30 UTC
   1995-12-22T09:05:02 = Ijumaa, 1995 Desemba 22 09:05:02 UTC
  -0010-12-22T23:05:02 = Jumamosi, -010 Desemba 22 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008 Februari 5 12:30:30 UTC
   1995-12-22T09:05:02 = 1995 Desemba 22 09:05:02 UTC
  -0010-12-22T23:05:02 = -010 Desemba 22 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008 Feb 5 12:30:30
   1995-12-22T09:05:02 = 1995 Des 22 09:05:02
  -0010-12-22T23:05:02 = -010 Des 22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8/02/05 12:30
   1995-12-22T09:05:02 = 95/12/22 09:05
  -0010-12-22T23:05:02 = 10/12/22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008 Feb 5 12:30:30
   1995-12-22T09:05:02 = 1995 Des 22 09:05:02
  -0010-12-22T23:05:02 = -010 Des 22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = Jnn 5
   1995-12-22T09:05:02 = Iju 22
  -0010-12-22T23:05:02 = Jmo 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = Jnn Feb 5
   1995-12-22T09:05:02 = Iju Des 22
  -0010-12-22T23:05:02 = Jmo Des 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = Februari 5
   1995-12-22T09:05:02 = Desemba 22
  -0010-12-22T23:05:02 = Desemba 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 Feb
   1995-12-22T09:05:02 = 95 Des
  -0010-12-22T23:05:02 = 10 Des

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Jumatatu


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
