###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file lv.xml
# The source file version number was 1.70, generated on
# 2007/07/19 23:40:49.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::lv;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

{
    my $am_pm_abbreviated = [ "AM", "PM" ];
    sub am_pm_abbreviated { return $am_pm_abbreviated }
}
{
    my $date_format_full = "EEEE\,\ yyyy\.\ \'gada\'\ d\.\ MMMM";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "yyyy\.\ \'gada\'\ d\.\ MMMM";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "yyyy\.d\.M";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yy\.d\.M";
    sub date_format_short { return $date_format_short }
}

{
    my $datetime_format = "\{1\}\ \{0\}";
    sub datetime_format { return $datetime_format }
}

{
    my $day_format_abbreviated = [ "P", "O", "T", "C", "Pk", "S", "Sv" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "pirmdiena", "otrdiena", "trešdiena", "ceturtdiena", "piektdiena", "sestdiena", "svētdiena" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "2", "3", "4", "5", "6", "7", "1" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "pmē", "mē" ];
    sub era_abbreviated { return $era_abbreviated }
}
{
    my $era_narrow = [ "p\.m\.ē\.", "m\.ē\." ];
    sub era_narrow { return $era_narrow }
}
{
    my $era_wide = [ "pirms\ mūsu\ ēras", "mūsu\ ērā" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "Jan", "Feb", "Mar", "Apr", "Mai", "Jūn", "Jūl", "Aug", "Sep", "Okt", "Nov", "Dec" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "janvāris", "februāris", "marts", "aprīlis", "maijs", "jūnijs", "jūlijs", "augusts", "septembris", "oktobris", "novembris", "decembris" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "C1", "C2", "C3", "C4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}
{
    my $quarter_format_wide = [ "1\.\ ceturksnis", "2\.\ ceturksnis", "3\.\ ceturksnis", "4\.\ ceturksnis" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }


sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "HH\:mm\:ss\ v";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "HH\:mm\:ss\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "HH\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "HH\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_Ed = "E\ d";
    sub _format_for_Ed { return $_format_for_Ed }
}

{
    my $_format_for_H = "H";
    sub _format_for_H { return $_format_for_H }
}

{
    my $_format_for_HHmm = "HH\:mm";
    sub _format_for_HHmm { return $_format_for_HHmm }
}

{
    my $_format_for_HHmmss = "HH\:mm\:ss";
    sub _format_for_HHmmss { return $_format_for_HHmmss }
}

{
    my $_format_for_MMMMd = "d\.\ MMMM";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_Md = "d\.M";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_mmss = "mm\:ss";
    sub _format_for_mmss { return $_format_for_mmss }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyy = "yyyy\.\ \'g\'\.";
    sub _format_for_yyyy { return $_format_for_yyyy }
}

{
    my $_available_formats =
        {
          "Ed" => "E\ d",
          "H" => "H",
          "HHmm" => "HH\:mm",
          "HHmmss" => "HH\:mm\:ss",
          "MMMMd" => "d\.\ MMMM",
          "Md" => "d\.M",
          "mmss" => "mm\:ss",
          "yyQ" => "Q\ yy",
          "yyyy" => "yyyy\.\ \'g\'\."
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::lv

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'lv' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Latvian.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  pirmdiena
  otrdiena
  trešdiena
  ceturtdiena
  piektdiena
  sestdiena
  svētdiena

=head3 Abbreviated (format)

  P
  O
  T
  C
  Pk
  S
  Sv

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  pirmdiena
  otrdiena
  trešdiena
  ceturtdiena
  piektdiena
  sestdiena
  svētdiena

=head3 Abbreviated (stand-alone)

  P
  O
  T
  C
  Pk
  S
  Sv

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  janvāris
  februāris
  marts
  aprīlis
  maijs
  jūnijs
  jūlijs
  augusts
  septembris
  oktobris
  novembris
  decembris

=head3 Abbreviated (format)

  Jan
  Feb
  Mar
  Apr
  Mai
  Jūn
  Jūl
  Aug
  Sep
  Okt
  Nov
  Dec

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  janvāris
  februāris
  marts
  aprīlis
  maijs
  jūnijs
  jūlijs
  augusts
  septembris
  oktobris
  novembris
  decembris

=head3 Abbreviated (stand-alone)

  Jan
  Feb
  Mar
  Apr
  Mai
  Jūn
  Jūl
  Aug
  Sep
  Okt
  Nov
  Dec

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  1. ceturksnis
  2. ceturksnis
  3. ceturksnis
  4. ceturksnis

=head3 Abbreviated (format)

  C1
  C2
  C3
  C4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1. ceturksnis
  2. ceturksnis
  3. ceturksnis
  4. ceturksnis

=head3 Abbreviated (stand-alone)

  C1
  C2
  C3
  C4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  pirms mūsu ēras
  mūsu ērā

=head3 Abbreviated

  pmē
  mē

=head3 Narrow

  p.m.ē.
  m.ē.

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = otrdiena, 2008. gada 5. februāris
   1995-12-22T09:05:02 = piektdiena, 1995. gada 22. decembris
  -0010-12-22T23:05:02 = sestdiena, -010. gada 22. decembris

=head3 Long

   2008-02-05T12:30:30 = 2008. gada 5. februāris
   1995-12-22T09:05:02 = 1995. gada 22. decembris
  -0010-12-22T23:05:02 = -010. gada 22. decembris

=head3 Medium

   2008-02-05T12:30:30 = 2008.5.2
   1995-12-22T09:05:02 = 1995.22.12
  -0010-12-22T23:05:02 = -010.22.12

=head3 Short

   2008-02-05T12:30:30 = 8.5.2
   1995-12-22T09:05:02 = 95.22.12
  -0010-12-22T23:05:02 = 10.22.12

=head3 Default

   2008-02-05T12:30:30 = 2008.5.2
   1995-12-22T09:05:02 = 1995.22.12
  -0010-12-22T23:05:02 = -010.22.12

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = otrdiena, 2008. gada 5. februāris 12:30:30 UTC
   1995-12-22T09:05:02 = piektdiena, 1995. gada 22. decembris 09:05:02 UTC
  -0010-12-22T23:05:02 = sestdiena, -010. gada 22. decembris 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008. gada 5. februāris 12:30:30 UTC
   1995-12-22T09:05:02 = 1995. gada 22. decembris 09:05:02 UTC
  -0010-12-22T23:05:02 = -010. gada 22. decembris 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008.5.2 12:30:30
   1995-12-22T09:05:02 = 1995.22.12 09:05:02
  -0010-12-22T23:05:02 = -010.22.12 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8.5.2 12:30
   1995-12-22T09:05:02 = 95.22.12 09:05
  -0010-12-22T23:05:02 = 10.22.12 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008.5.2 12:30:30
   1995-12-22T09:05:02 = 1995.22.12 09:05:02
  -0010-12-22T23:05:02 = -010.22.12 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = O 5
   1995-12-22T09:05:02 = Pk 22
  -0010-12-22T23:05:02 = S 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = O Feb 5
   1995-12-22T09:05:02 = Pk Dec 22
  -0010-12-22T23:05:02 = S Dec 22

=head3 MMMMd (d. MMMM)

   2008-02-05T12:30:30 = 5. februāris
   1995-12-22T09:05:02 = 22. decembris
  -0010-12-22T23:05:02 = 22. decembris

=head3 Md (d.M)

   2008-02-05T12:30:30 = 5.2
   1995-12-22T09:05:02 = 22.12
  -0010-12-22T23:05:02 = 22.12

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 Feb
   1995-12-22T09:05:02 = 95 Dec
  -0010-12-22T23:05:02 = 10 Dec

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy. 'g'.)

   2008-02-05T12:30:30 = 2008. g.
   1995-12-22T09:05:02 = 1995. g.
  -0010-12-22T23:05:02 = -010. g.

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

pirmdiena


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
