###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file zh_Hant.xml
# The source file version number was 1.91, generated on
# 2007/11/29 18:23:45.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::zh_Hant;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::zh';

{
    my $date_format_medium = "yyyy\/M\/d";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "yyyy\/M\/d";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "週一", "週二", "週三", "週四", "週五", "週六", "週日" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_format_abbreviated() }


sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }


sub era_abbreviated { $_[0]->era_wide() }

{
    my $era_wide = [ "西元前", "西元" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $quarter_format_abbreviated = [ "1季", "2季", "3季", "4季" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}
{
    my $quarter_format_wide = [ "第1季", "第2季", "第3季", "第4季" ];
    sub quarter_format_wide { return $quarter_format_wide }
}
{
    my $quarter_stand_alone_abbreviated = [ "1季", "2季", "3季", "4季" ];
    sub quarter_stand_alone_abbreviated { return $quarter_stand_alone_abbreviated }
}

sub quarter_stand_alone_wide { $_[0]->quarter_format_wide() }

{
    my $time_format_full = "ahh時mm分ss秒\ v";
    sub time_format_full { return $time_format_full }
}

{
    my $time_format_long = "ahh時mm分ss秒\ z";
    sub time_format_long { return $time_format_long }
}

{
    my $time_format_medium = "a\ h\:mm\:ss";
    sub time_format_medium { return $time_format_medium }
}

{
    my $time_format_short = "a\ h\:mm";
    sub time_format_short { return $time_format_short }
}

{
    my $_format_for_MMMMd = "MMMM\ d";
    sub _format_for_MMMMd { return $_format_for_MMMMd }
}

{
    my $_format_for_Md = "M\/d";
    sub _format_for_Md { return $_format_for_Md }
}

{
    my $_format_for_yyMMM = "yy\ MMM";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_format_for_yyQ = "Q\ yy";
    sub _format_for_yyQ { return $_format_for_yyQ }
}

{
    my $_format_for_yyyyM = "yyyy\/M";
    sub _format_for_yyyyM { return $_format_for_yyyyM }
}

{
    my $_available_formats =
        {
          "MMMMd" => "MMMM\ d",
          "Md" => "M\/d",
          "yyMMM" => "yy\ MMM",
          "yyQ" => "Q\ yy",
          "yyyyM" => "yyyy\/M"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::zh_Hant

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'zh_Hant' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Chinese Traditional Han.

=head1 DATA

This locale inherits from the L<DateTime::Locale::zh> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  星期一
  星期二
  星期三
  星期四
  星期五
  星期六
  星期日

=head3 Abbreviated (format)

  週一
  週二
  週三
  週四
  週五
  週六
  週日

=head3 Narrow (format)

  週一
  週二
  週三
  週四
  週五
  週六
  週日

=head3 Wide (stand-alone)

  星期一
  星期二
  星期三
  星期四
  星期五
  星期六
  星期日

=head3 Abbreviated (stand-alone)

  週一
  週二
  週三
  週四
  週五
  週六
  週日

=head3 Narrow (stand-alone)

  一
  二
  三
  四
  五
  六
  日

=head2 Months

=head3 Wide (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Abbreviated (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Narrow (format)

  1月
  2月
  3月
  4月
  5月
  6月
  7月
  8月
  9月
  10月
  11月
  12月

=head3 Wide (stand-alone)

  一月
  二月
  三月
  四月
  五月
  六月
  七月
  八月
  九月
  十月
  十一月
  十二月

=head3 Abbreviated (stand-alone)

  一月
  二月
  三月
  四月
  五月
  六月
  七月
  八月
  九月
  十月
  十一月
  十二月

=head3 Narrow (stand-alone)

  1月
  2月
  3月
  4月
  5月
  6月
  7月
  8月
  9月
  10月
  11月
  12月

=head2 Quarters

=head3 Wide (format)

  第1季
  第2季
  第3季
  第4季

=head3 Abbreviated (format)

  1季
  2季
  3季
  4季

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  第1季
  第2季
  第3季
  第4季

=head3 Abbreviated (stand-alone)

  1季
  2季
  3季
  4季

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  西元前
  西元

=head3 Abbreviated

  西元前
  西元

=head3 Narrow

  西元前
  西元

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = 2008年2月5日星期二
   1995-12-22T09:05:02 = 1995年12月22日星期五
  -0010-12-22T23:05:02 = -010年12月22日星期六

=head3 Long

   2008-02-05T12:30:30 = 2008年2月5日
   1995-12-22T09:05:02 = 1995年12月22日
  -0010-12-22T23:05:02 = -010年12月22日

=head3 Medium

   2008-02-05T12:30:30 = 2008/2/5
   1995-12-22T09:05:02 = 1995/12/22
  -0010-12-22T23:05:02 = -010/12/22

=head3 Short

   2008-02-05T12:30:30 = 2008/2/5
   1995-12-22T09:05:02 = 1995/12/22
  -0010-12-22T23:05:02 = -010/12/22

=head3 Default

   2008-02-05T12:30:30 = 2008/2/5
   1995-12-22T09:05:02 = 1995/12/22
  -0010-12-22T23:05:02 = -010/12/22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 下午12時30分30秒 UTC
   1995-12-22T09:05:02 = 上午09時05分02秒 UTC
  -0010-12-22T23:05:02 = 下午11時05分02秒 UTC

=head3 Long

   2008-02-05T12:30:30 = 下午12時30分30秒 UTC
   1995-12-22T09:05:02 = 上午09時05分02秒 UTC
  -0010-12-22T23:05:02 = 下午11時05分02秒 UTC

=head3 Medium

   2008-02-05T12:30:30 = 下午 12:30:30
   1995-12-22T09:05:02 = 上午 9:05:02
  -0010-12-22T23:05:02 = 下午 11:05:02

=head3 Short

   2008-02-05T12:30:30 = 下午 12:30
   1995-12-22T09:05:02 = 上午 9:05
  -0010-12-22T23:05:02 = 下午 11:05

=head3 Default

   2008-02-05T12:30:30 = 下午 12:30:30
   1995-12-22T09:05:02 = 上午 9:05:02
  -0010-12-22T23:05:02 = 下午 11:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = 2008年2月5日星期二 下午12時30分30秒 UTC
   1995-12-22T09:05:02 = 1995年12月22日星期五 上午09時05分02秒 UTC
  -0010-12-22T23:05:02 = -010年12月22日星期六 下午11時05分02秒 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008年2月5日 下午12時30分30秒 UTC
   1995-12-22T09:05:02 = 1995年12月22日 上午09時05分02秒 UTC
  -0010-12-22T23:05:02 = -010年12月22日 下午11時05分02秒 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008/2/5 下午 12:30:30
   1995-12-22T09:05:02 = 1995/12/22 上午 9:05:02
  -0010-12-22T23:05:02 = -010/12/22 下午 11:05:02

=head3 Short

   2008-02-05T12:30:30 = 2008/2/5 下午 12:30
   1995-12-22T09:05:02 = 1995/12/22 上午 9:05
  -0010-12-22T23:05:02 = -010/12/22 下午 11:05

=head3 Default

   2008-02-05T12:30:30 = 2008/2/5 下午 12:30:30
   1995-12-22T09:05:02 = 1995/12/22 上午 9:05:02
  -0010-12-22T23:05:02 = -010/12/22 下午 11:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = 週二 5
   1995-12-22T09:05:02 = 週五 22
  -0010-12-22T23:05:02 = 週六 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = 週二 2 5
   1995-12-22T09:05:02 = 週五 12 22
  -0010-12-22T23:05:02 = 週六 12 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = 2 5
   1995-12-22T09:05:02 = 12 22
  -0010-12-22T23:05:02 = 12 22

=head3 MMMMdd (dd MMMM)

   2008-02-05T12:30:30 = 05 2
   1995-12-22T09:05:02 = 22 12
  -0010-12-22T23:05:02 = 22 12

=head3 MMdd (dd/MM)

   2008-02-05T12:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-12-22T23:05:02 = 22/12

=head3 Md (M/d)

   2008-02-05T12:30:30 = 2/5
   1995-12-22T09:05:02 = 12/22
  -0010-12-22T23:05:02 = 12/22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 2
   1995-12-22T09:05:02 = 95 12
  -0010-12-22T23:05:02 = 10 12

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head3 yyyyM (yyyy/M)

   2008-02-05T12:30:30 = 2008/2
   1995-12-22T09:05:02 = 1995/12
  -0010-12-22T23:05:02 = -010/12

=head3 yyyyMMMM (MMMM yyyy)

   2008-02-05T12:30:30 = 2 2008
   1995-12-22T09:05:02 = 12 1995
  -0010-12-22T23:05:02 = 12 -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

No

=head3 Local first day of the week

星期一


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
