###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file fil.xml
# The source file version number was 1.8, generated on
# 2007/11/20 02:39:11.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fil;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::root';

{
    my $date_format_full = "EEEE\,\ MMMM\ dd\ yyyy";
    sub date_format_full { return $date_format_full }
}

{
    my $date_format_long = "MMMM\ d\,\ yyyy";
    sub date_format_long { return $date_format_long }
}

{
    my $date_format_medium = "MMM\ d\,\ yyyy";
    sub date_format_medium { return $date_format_medium }
}

{
    my $date_format_short = "M\/d\/yy";
    sub date_format_short { return $date_format_short }
}

{
    my $day_format_abbreviated = [ "Lun", "Mar", "Mye", "Huw", "Bye", "Sab", "Lin" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "Lunes", "Martes", "Miyerkules", "Huwebes", "Biyernes", "Sabado", "Linggo" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "L", "M", "M", "H", "B", "S", "L" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}
{
    my $day_stand_alone_wide = [ "Lunes", "Martes", "Miyerkules", "Huwebes", "Biyernes", "Sabado", "Linggo" ];
    sub day_stand_alone_wide { return $day_stand_alone_wide }
}
{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "Ene", "Peb", "Mar", "Abr", "May", "Hun", "Hul", "Ago", "Set", "Okt", "Nob", "Dis" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "Enero", "Pebrero", "Marso", "Abril", "Mayo", "Hunyo", "Hulyo", "Agosto", "Setyembre", "Oktubre", "Nobyembre", "Disyembre" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "E", "P", "M", "A", "M", "H", "H", "A", "S", "O", "N", "D" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}
{
    my $month_stand_alone_wide = [ "Enero", "Pebrero", "Marso", "Abril", "Mayo", "Hunyo", "Hulyo", "Agosto", "Setyembre", "Oktubre", "Nobyembre", "Disyembre" ];
    sub month_stand_alone_wide { return $month_stand_alone_wide }
}
{
    my $_format_for_yyMM = "yy\-MM";
    sub _format_for_yyMM { return $_format_for_yyMM }
}

{
    my $_format_for_yyMMM = "MMM\ yy";
    sub _format_for_yyMMM { return $_format_for_yyMMM }
}

{
    my $_available_formats =
        {
          "yyMM" => "yy\-MM",
          "yyMMM" => "MMM\ yy"
        };
    sub _available_formats { return $_available_formats }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::fil

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'fil' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Filipino.

=head1 DATA

This locale inherits from the L<DateTime::Locale::root> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Lunes
  Martes
  Miyerkules
  Huwebes
  Biyernes
  Sabado
  Linggo

=head3 Abbreviated (format)

  Lun
  Mar
  Mye
  Huw
  Bye
  Sab
  Lin

=head3 Narrow (format)

  L
  M
  M
  H
  B
  S
  L

=head3 Wide (stand-alone)

  Lunes
  Martes
  Miyerkules
  Huwebes
  Biyernes
  Sabado
  Linggo

=head3 Abbreviated (stand-alone)

  Lun
  Mar
  Mye
  Huw
  Bye
  Sab
  Lin

=head3 Narrow (stand-alone)

  L
  M
  M
  H
  B
  S
  L

=head2 Months

=head3 Wide (format)

  Enero
  Pebrero
  Marso
  Abril
  Mayo
  Hunyo
  Hulyo
  Agosto
  Setyembre
  Oktubre
  Nobyembre
  Disyembre

=head3 Abbreviated (format)

  Ene
  Peb
  Mar
  Abr
  May
  Hun
  Hul
  Ago
  Set
  Okt
  Nob
  Dis

=head3 Narrow (format)

  E
  P
  M
  A
  M
  H
  H
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  Enero
  Pebrero
  Marso
  Abril
  Mayo
  Hunyo
  Hulyo
  Agosto
  Setyembre
  Oktubre
  Nobyembre
  Disyembre

=head3 Abbreviated (stand-alone)

  Ene
  Peb
  Mar
  Abr
  May
  Hun
  Hul
  Ago
  Set
  Okt
  Nob
  Dis

=head3 Narrow (stand-alone)

  E
  P
  M
  A
  M
  H
  H
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  BCE
  CE

=head3 Narrow

  BCE
  CE

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = Martes, Pebrero 05 2008
   1995-12-22T09:05:02 = Biyernes, Disyembre 22 1995
  -0010-12-22T23:05:02 = Sabado, Disyembre 22 -010

=head3 Long

   2008-02-05T12:30:30 = Pebrero 5, 2008
   1995-12-22T09:05:02 = Disyembre 22, 1995
  -0010-12-22T23:05:02 = Disyembre 22, -010

=head3 Medium

   2008-02-05T12:30:30 = Peb 5, 2008
   1995-12-22T09:05:02 = Dis 22, 1995
  -0010-12-22T23:05:02 = Dis 22, -010

=head3 Short

   2008-02-05T12:30:30 = 2/5/8
   1995-12-22T09:05:02 = 12/22/95
  -0010-12-22T23:05:02 = 12/22/10

=head3 Default

   2008-02-05T12:30:30 = Peb 5, 2008
   1995-12-22T09:05:02 = Dis 22, 1995
  -0010-12-22T23:05:02 = Dis 22, -010

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = Martes, Pebrero 05 2008 12:30:30 UTC
   1995-12-22T09:05:02 = Biyernes, Disyembre 22 1995 09:05:02 UTC
  -0010-12-22T23:05:02 = Sabado, Disyembre 22 -010 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = Pebrero 5, 2008 12:30:30 UTC
   1995-12-22T09:05:02 = Disyembre 22, 1995 09:05:02 UTC
  -0010-12-22T23:05:02 = Disyembre 22, -010 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = Peb 5, 2008 12:30:30
   1995-12-22T09:05:02 = Dis 22, 1995 09:05:02
  -0010-12-22T23:05:02 = Dis 22, -010 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 2/5/8 12:30
   1995-12-22T09:05:02 = 12/22/95 09:05
  -0010-12-22T23:05:02 = 12/22/10 23:05

=head3 Default

   2008-02-05T12:30:30 = Peb 5, 2008 12:30:30
   1995-12-22T09:05:02 = Dis 22, 1995 09:05:02
  -0010-12-22T23:05:02 = Dis 22, -010 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = Mar 5
   1995-12-22T09:05:02 = Bye 22
  -0010-12-22T23:05:02 = Sab 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = Mar Peb 5
   1995-12-22T09:05:02 = Bye Dis 22
  -0010-12-22T23:05:02 = Sab Dis 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = Pebrero 5
   1995-12-22T09:05:02 = Disyembre 22
  -0010-12-22T23:05:02 = Disyembre 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (MMM yy)

   2008-02-05T12:30:30 = Peb 8
   1995-12-22T09:05:02 = Dis 95
  -0010-12-22T23:05:02 = Dis 10

=head3 yyQ (yy Q)

   2008-02-05T12:30:30 = 8 1
   1995-12-22T09:05:02 = 95 4
  -0010-12-22T23:05:02 = 10 4

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Lunes


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
