###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file uz_Latn_UZ.xml
# The source file version number was 1.17, generated on
# 2007/07/14 23:02:17.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::uz_Latn_UZ;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::uz_Latn';

{
    my $first_day_of_week = 7;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::uz_Latn_UZ

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'uz_Latn_UZ' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Uzbek Latin Uzbekistan.

=head1 DATA

This locale inherits from the L<DateTime::Locale::uz_Latn> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  dushanba
  seshanba
  chorshanba
  payshanba
  juma
  shanba
  yakshanba

=head3 Abbreviated (format)

  Dush
  Sesh
  Chor
  Pay
  Jum
  Shan
  Yaksh

=head3 Narrow (format)

  D
  S
  C
  P
  J
  S
  Y

=head3 Wide (stand-alone)

  dushanba
  seshanba
  chorshanba
  payshanba
  juma
  shanba
  yakshanba

=head3 Abbreviated (stand-alone)

  Dush
  Sesh
  Chor
  Pay
  Jum
  Shan
  Yaksh

=head3 Narrow (stand-alone)

  D
  S
  C
  P
  J
  S
  Y

=head2 Months

=head3 Wide (format)

  Muharram
  Safar
  Rabiul-avval
  Rabiul-oxir
  Jumodiul-ulo
  Jumodiul-uxro
  Rajab
  Shaʿbon
  Ramazon
  Shavvol
  Zil-qaʿda
  Zil-hijja

=head3 Abbreviated (format)

  Yanv
  Fev
  Mar
  Apr
  May
  Iyun
  Iyul
  Avg
  Sen
  Okt
  Noya
  Dek

=head3 Narrow (format)

  Y
  F
  M
  A
  M
  I
  I
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  Muharram
  Safar
  Rabiul-avval
  Rabiul-oxir
  Jumodiul-ulo
  Jumodiul-uxro
  Rajab
  Shaʿbon
  Ramazon
  Shavvol
  Zil-qaʿda
  Zil-hijja

=head3 Abbreviated (stand-alone)

  Yanv
  Fev
  Mar
  Apr
  May
  Iyun
  Iyul
  Avg
  Sen
  Okt
  Noya
  Dek

=head3 Narrow (stand-alone)

  Y
  F
  M
  A
  M
  I
  I
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  BCE
  CE

=head3 Narrow

  BCE
  CE

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = seshanba, 2008 Safar 05
   1995-12-22T09:05:02 = juma, 1995 Zil-hijja 22
  -0010-12-22T23:05:02 = shanba, -010 Zil-hijja 22

=head3 Long

   2008-02-05T12:30:30 = 2008 Safar 5
   1995-12-22T09:05:02 = 1995 Zil-hijja 22
  -0010-12-22T23:05:02 = -010 Zil-hijja 22

=head3 Medium

   2008-02-05T12:30:30 = 2008 Fev 5
   1995-12-22T09:05:02 = 1995 Dek 22
  -0010-12-22T23:05:02 = -010 Dek 22

=head3 Short

   2008-02-05T12:30:30 = 8/02/05
   1995-12-22T09:05:02 = 95/12/22
  -0010-12-22T23:05:02 = 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 2008 Fev 5
   1995-12-22T09:05:02 = 1995 Dek 22
  -0010-12-22T23:05:02 = -010 Dek 22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = seshanba, 2008 Safar 05 12:30:30 UTC
   1995-12-22T09:05:02 = juma, 1995 Zil-hijja 22 09:05:02 UTC
  -0010-12-22T23:05:02 = shanba, -010 Zil-hijja 22 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008 Safar 5 12:30:30 UTC
   1995-12-22T09:05:02 = 1995 Zil-hijja 22 09:05:02 UTC
  -0010-12-22T23:05:02 = -010 Zil-hijja 22 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008 Fev 5 12:30:30
   1995-12-22T09:05:02 = 1995 Dek 22 09:05:02
  -0010-12-22T23:05:02 = -010 Dek 22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8/02/05 12:30
   1995-12-22T09:05:02 = 95/12/22 09:05
  -0010-12-22T23:05:02 = 10/12/22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008 Fev 5 12:30:30
   1995-12-22T09:05:02 = 1995 Dek 22 09:05:02
  -0010-12-22T23:05:02 = -010 Dek 22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = Sesh 5
   1995-12-22T09:05:02 = Jum 22
  -0010-12-22T23:05:02 = Shan 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = Sesh Fev 5
   1995-12-22T09:05:02 = Jum Dek 22
  -0010-12-22T23:05:02 = Shan Dek 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = Safar 5
   1995-12-22T09:05:02 = Zil-hijja 22
  -0010-12-22T23:05:02 = Zil-hijja 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 Fev
   1995-12-22T09:05:02 = 95 Dek
  -0010-12-22T23:05:02 = 10 Dek

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head3 yyyyM (yyyy/M)

   2008-02-05T12:30:30 = 2008/2
   1995-12-22T09:05:02 = 1995/12
  -0010-12-22T23:05:02 = -010/12

=head3 yyyyMMMM (MMMM yyyy)

   2008-02-05T12:30:30 = Safar 2008
   1995-12-22T09:05:02 = Zil-hijja 1995
  -0010-12-22T23:05:02 = Zil-hijja -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

yakshanba


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
