###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file eu_ES.xml
# The source file version number was 1.45, generated on
# 2007/07/19 22:31:39.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::eu_ES;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::eu';

{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::eu_ES

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'eu_ES' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Basque Spain.

=head1 DATA

This locale inherits from the L<DateTime::Locale::eu> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  astelehena
  asteartea
  asteazkena
  osteguna
  ostirala
  larunbata
  igandea

=head3 Abbreviated (format)

  al
  as
  az
  og
  or
  lr
  ig

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  astelehena
  asteartea
  asteazkena
  osteguna
  ostirala
  larunbata
  igandea

=head3 Abbreviated (stand-alone)

  al
  as
  az
  og
  or
  lr
  ig

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  urtarrila
  otsaila
  martxoa
  apirila
  maiatza
  ekaina
  uztaila
  abuztua
  iraila
  urria
  azaroa
  abendua

=head3 Abbreviated (format)

  urt
  ots
  mar
  api
  mai
  eka
  uzt
  abu
  ira
  urr
  aza
  abe

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  urtarrila
  otsaila
  martxoa
  apirila
  maiatza
  ekaina
  uztaila
  abuztua
  iraila
  urria
  azaroa
  abendua

=head3 Abbreviated (stand-alone)

  urt
  ots
  mar
  api
  mai
  eka
  uzt
  abu
  ira
  urr
  aza
  abe

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  1. hiruhilekoa
  2. hiruhilekoa
  3. hiruhilekoa
  4. hiruhilekoa

=head3 Abbreviated (format)

  Hh1
  Hh2
  Hh3
  Hh4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  1. hiruhilekoa
  2. hiruhilekoa
  3. hiruhilekoa
  4. hiruhilekoa

=head3 Abbreviated (stand-alone)

  Hh1
  Hh2
  Hh3
  Hh4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  BCE
  CE

=head3 Narrow

  BCE
  CE

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = asteartea, 2008eko otsailaren 05a
   1995-12-22T09:05:02 = ostirala, 1995eko abenduaren 22a
  -0010-12-22T23:05:02 = larunbata, -010eko abenduaren 22a

=head3 Long

   2008-02-05T12:30:30 = 2008eko otsren 05a
   1995-12-22T09:05:02 = 1995eko aberen 22a
  -0010-12-22T23:05:02 = -010eko aberen 22a

=head3 Medium

   2008-02-05T12:30:30 = 2008-ots-05
   1995-12-22T09:05:02 = 1995-abe-22
  -0010-12-22T23:05:02 = -010-abe-22

=head3 Short

   2008-02-05T12:30:30 = 8-02-05
   1995-12-22T09:05:02 = 95-12-22
  -0010-12-22T23:05:02 = 10-12-22

=head3 Default

   2008-02-05T12:30:30 = 2008-ots-05
   1995-12-22T09:05:02 = 1995-abe-22
  -0010-12-22T23:05:02 = -010-abe-22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = asteartea, 2008eko otsailaren 05a 12:30:30 UTC
   1995-12-22T09:05:02 = ostirala, 1995eko abenduaren 22a 09:05:02 UTC
  -0010-12-22T23:05:02 = larunbata, -010eko abenduaren 22a 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008eko otsren 05a 12:30:30 UTC
   1995-12-22T09:05:02 = 1995eko aberen 22a 09:05:02 UTC
  -0010-12-22T23:05:02 = -010eko aberen 22a 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008-ots-05 12:30:30
   1995-12-22T09:05:02 = 1995-abe-22 09:05:02
  -0010-12-22T23:05:02 = -010-abe-22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8-02-05 12:30
   1995-12-22T09:05:02 = 95-12-22 09:05
  -0010-12-22T23:05:02 = 10-12-22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008-ots-05 12:30:30
   1995-12-22T09:05:02 = 1995-abe-22 09:05:02
  -0010-12-22T23:05:02 = -010-abe-22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = as 5
   1995-12-22T09:05:02 = or 22
  -0010-12-22T23:05:02 = lr 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = as ots 5
   1995-12-22T09:05:02 = or abe 22
  -0010-12-22T23:05:02 = lr abe 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = otsaila 5
   1995-12-22T09:05:02 = abendua 22
  -0010-12-22T23:05:02 = abendua 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 ots
   1995-12-22T09:05:02 = 95 abe
  -0010-12-22T23:05:02 = 10 abe

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

astelehena


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
