###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file sid_ET.xml
# The source file version number was 1.32, generated on
# 2007/07/14 23:02:16.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sid_ET;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::sid';

{
    my $first_day_of_week = 7;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::sid_ET

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'sid_ET' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Sidamo Ethiopia.

=head1 DATA

This locale inherits from the L<DateTime::Locale::sid> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Sanyo
  Maakisanyo
  Roowe
  Hamuse
  Arbe
  Qidaame
  Sambata

=head3 Abbreviated (format)

  San
  Mak
  Row
  Ham
  Arb
  Qid
  Sam

=head3 Narrow (format)

  S
  M
  R
  H
  A
  Q
  S

=head3 Wide (stand-alone)

  Sanyo
  Maakisanyo
  Roowe
  Hamuse
  Arbe
  Qidaame
  Sambata

=head3 Abbreviated (stand-alone)

  San
  Mak
  Row
  Ham
  Arb
  Qid
  Sam

=head3 Narrow (stand-alone)

  S
  M
  R
  H
  A
  Q
  S

=head2 Months

=head3 Wide (format)

  January
  February
  March
  April
  May
  June
  July
  August
  September
  October
  November
  December

=head3 Abbreviated (format)

  Jan
  Feb
  Mar
  Apr
  May
  Jun
  Jul
  Aug
  Sep
  Oct
  Nov
  Dec

=head3 Narrow (format)

  J
  F
  M
  A
  M
  J
  J
  A
  S
  O
  N
  D

=head3 Wide (stand-alone)

  January
  February
  March
  April
  May
  June
  July
  August
  September
  October
  November
  December

=head3 Abbreviated (stand-alone)

  Jan
  Feb
  Mar
  Apr
  May
  Jun
  Jul
  Aug
  Sep
  Oct
  Nov
  Dec

=head3 Narrow (stand-alone)

  J
  F
  M
  A
  M
  J
  J
  A
  S
  O
  N
  D

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  YIA
  YIG

=head3 Narrow

  YIA
  YIG

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = Maakisanyo, February 05, 2008
   1995-12-22T09:05:02 = Arbe, December 22, 1995
  -0010-12-22T23:05:02 = Qidaame, December 22, -010

=head3 Long

   2008-02-05T12:30:30 = 05 February 2008
   1995-12-22T09:05:02 = 22 December 1995
  -0010-12-22T23:05:02 = 22 December -010

=head3 Medium

   2008-02-05T12:30:30 = 05-Feb-2008
   1995-12-22T09:05:02 = 22-Dec-1995
  -0010-12-22T23:05:02 = 22-Dec--010

=head3 Short

   2008-02-05T12:30:30 = 05/02/8
   1995-12-22T09:05:02 = 22/12/95
  -0010-12-22T23:05:02 = 22/12/10

=head3 Default

   2008-02-05T12:30:30 = 05-Feb-2008
   1995-12-22T09:05:02 = 22-Dec-1995
  -0010-12-22T23:05:02 = 22-Dec--010

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 hawwaro UTC
   1995-12-22T09:05:02 = 9:05:02 soodo UTC
  -0010-12-22T23:05:02 = 11:05:02 hawwaro UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 hawwaro UTC
   1995-12-22T09:05:02 = 9:05:02 soodo UTC
  -0010-12-22T23:05:02 = 11:05:02 hawwaro UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30 hawwaro
   1995-12-22T09:05:02 = 9:05:02 soodo
  -0010-12-22T23:05:02 = 11:05:02 hawwaro

=head3 Short

   2008-02-05T12:30:30 = 12:30 hawwaro
   1995-12-22T09:05:02 = 9:05 soodo
  -0010-12-22T23:05:02 = 11:05 hawwaro

=head3 Default

   2008-02-05T12:30:30 = 12:30:30 hawwaro
   1995-12-22T09:05:02 = 9:05:02 soodo
  -0010-12-22T23:05:02 = 11:05:02 hawwaro

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = Maakisanyo, February 05, 2008 12:30:30 hawwaro UTC
   1995-12-22T09:05:02 = Arbe, December 22, 1995 9:05:02 soodo UTC
  -0010-12-22T23:05:02 = Qidaame, December 22, -010 11:05:02 hawwaro UTC

=head3 Long

   2008-02-05T12:30:30 = 05 February 2008 12:30:30 hawwaro UTC
   1995-12-22T09:05:02 = 22 December 1995 9:05:02 soodo UTC
  -0010-12-22T23:05:02 = 22 December -010 11:05:02 hawwaro UTC

=head3 Medium

   2008-02-05T12:30:30 = 05-Feb-2008 12:30:30 hawwaro
   1995-12-22T09:05:02 = 22-Dec-1995 9:05:02 soodo
  -0010-12-22T23:05:02 = 22-Dec--010 11:05:02 hawwaro

=head3 Short

   2008-02-05T12:30:30 = 05/02/8 12:30 hawwaro
   1995-12-22T09:05:02 = 22/12/95 9:05 soodo
  -0010-12-22T23:05:02 = 22/12/10 11:05 hawwaro

=head3 Default

   2008-02-05T12:30:30 = 05-Feb-2008 12:30:30 hawwaro
   1995-12-22T09:05:02 = 22-Dec-1995 9:05:02 soodo
  -0010-12-22T23:05:02 = 22-Dec--010 11:05:02 hawwaro

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = Mak 5
   1995-12-22T09:05:02 = Arb 22
  -0010-12-22T23:05:02 = Qid 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = Mak Feb 5
   1995-12-22T09:05:02 = Arb Dec 22
  -0010-12-22T23:05:02 = Qid Dec 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = February 5
   1995-12-22T09:05:02 = December 22
  -0010-12-22T23:05:02 = December 22

=head3 MMMMdd (dd MMMM)

   2008-02-05T12:30:30 = 05 February
   1995-12-22T09:05:02 = 22 December
  -0010-12-22T23:05:02 = 22 December

=head3 MMdd (dd/MM)

   2008-02-05T12:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-12-22T23:05:02 = 22/12

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (MM/yy)

   2008-02-05T12:30:30 = 02/8
   1995-12-22T09:05:02 = 12/95
  -0010-12-22T23:05:02 = 12/10

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 Feb
   1995-12-22T09:05:02 = 95 Dec
  -0010-12-22T23:05:02 = 10 Dec

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head3 yyyyMMMM (MMMM yyyy)

   2008-02-05T12:30:30 = February 2008
   1995-12-22T09:05:02 = December 1995
  -0010-12-22T23:05:02 = December -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

No

=head3 Local first day of the week

Sambata


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
