###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file gv_GB.xml
# The source file version number was 1.44, generated on
# 2007/07/19 22:31:39.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::gv_GB;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::gv';

{
    my $first_day_of_week = 7;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::gv_GB

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'gv_GB' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Manx United Kingdom.

=head1 DATA

This locale inherits from the L<DateTime::Locale::gv> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Jelhein
  Jemayrt
  Jercean
  Jerdein
  Jeheiney
  Jesarn
  Jedoonee

=head3 Abbreviated (format)

  Jel
  Jem
  Jerc
  Jerd
  Jeh
  Jes
  Jed

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  Jelhein
  Jemayrt
  Jercean
  Jerdein
  Jeheiney
  Jesarn
  Jedoonee

=head3 Abbreviated (stand-alone)

  Jel
  Jem
  Jerc
  Jerd
  Jeh
  Jes
  Jed

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  Jerrey-geuree
  Toshiaght-arree
  Mayrnt
  Averil
  Boaldyn
  Mean-souree
  Jerrey-souree
  Luanistyn
  Mean-fouyir
  Jerrey-fouyir
  Mee Houney
  Mee ny Nollick

=head3 Abbreviated (format)

  J-guer
  T-arree
  Mayrnt
  Avrril
  Boaldyn
  M-souree
  J-souree
  Luanistyn
  M-fouyir
  J-fouyir
  M.Houney
  M.Nollick

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  Jerrey-geuree
  Toshiaght-arree
  Mayrnt
  Averil
  Boaldyn
  Mean-souree
  Jerrey-souree
  Luanistyn
  Mean-fouyir
  Jerrey-fouyir
  Mee Houney
  Mee ny Nollick

=head3 Abbreviated (stand-alone)

  J-guer
  T-arree
  Mayrnt
  Avrril
  Boaldyn
  M-souree
  J-souree
  Luanistyn
  M-fouyir
  J-fouyir
  M.Houney
  M.Nollick

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  RC
  AD

=head3 Narrow

  RC
  AD

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = Jemayrt 05 Toshiaght-arree 2008
   1995-12-22T09:05:02 = Jeheiney 22 Mee ny Nollick 1995
  -0010-12-22T23:05:02 = Jesarn 22 Mee ny Nollick -010

=head3 Long

   2008-02-05T12:30:30 = 05 Toshiaght-arree 2008
   1995-12-22T09:05:02 = 22 Mee ny Nollick 1995
  -0010-12-22T23:05:02 = 22 Mee ny Nollick -010

=head3 Medium

   2008-02-05T12:30:30 = T-arree 05, 2008
   1995-12-22T09:05:02 = M.Nollick 22, 1995
  -0010-12-22T23:05:02 = M.Nollick 22, -010

=head3 Short

   2008-02-05T12:30:30 = 05/02/8
   1995-12-22T09:05:02 = 22/12/95
  -0010-12-22T23:05:02 = 22/12/10

=head3 Default

   2008-02-05T12:30:30 = T-arree 05, 2008
   1995-12-22T09:05:02 = M.Nollick 22, 1995
  -0010-12-22T23:05:02 = M.Nollick 22, -010

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = Jemayrt 05 Toshiaght-arree 2008 12:30:30 UTC
   1995-12-22T09:05:02 = Jeheiney 22 Mee ny Nollick 1995 09:05:02 UTC
  -0010-12-22T23:05:02 = Jesarn 22 Mee ny Nollick -010 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 05 Toshiaght-arree 2008 12:30:30 UTC
   1995-12-22T09:05:02 = 22 Mee ny Nollick 1995 09:05:02 UTC
  -0010-12-22T23:05:02 = 22 Mee ny Nollick -010 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = T-arree 05, 2008 12:30:30
   1995-12-22T09:05:02 = M.Nollick 22, 1995 09:05:02
  -0010-12-22T23:05:02 = M.Nollick 22, -010 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 05/02/8 12:30
   1995-12-22T09:05:02 = 22/12/95 09:05
  -0010-12-22T23:05:02 = 22/12/10 23:05

=head3 Default

   2008-02-05T12:30:30 = T-arree 05, 2008 12:30:30
   1995-12-22T09:05:02 = M.Nollick 22, 1995 09:05:02
  -0010-12-22T23:05:02 = M.Nollick 22, -010 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = Jem 5
   1995-12-22T09:05:02 = Jeh 22
  -0010-12-22T23:05:02 = Jes 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = Jem T-arree 5
   1995-12-22T09:05:02 = Jeh M.Nollick 22
  -0010-12-22T23:05:02 = Jes M.Nollick 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = Toshiaght-arree 5
   1995-12-22T09:05:02 = Mee ny Nollick 22
  -0010-12-22T23:05:02 = Mee ny Nollick 22

=head3 MMMMdd (dd MMMM)

   2008-02-05T12:30:30 = 05 Toshiaght-arree
   1995-12-22T09:05:02 = 22 Mee ny Nollick
  -0010-12-22T23:05:02 = 22 Mee ny Nollick

=head3 MMdd (dd/MM)

   2008-02-05T12:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-12-22T23:05:02 = 22/12

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (MM/yy)

   2008-02-05T12:30:30 = 02/8
   1995-12-22T09:05:02 = 12/95
  -0010-12-22T23:05:02 = 12/10

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 T-arree
   1995-12-22T09:05:02 = 95 M.Nollick
  -0010-12-22T23:05:02 = 10 M.Nollick

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head3 yyyyMMMM (MMMM yyyy)

   2008-02-05T12:30:30 = Toshiaght-arree 2008
   1995-12-22T09:05:02 = Mee ny Nollick 1995
  -0010-12-22T23:05:02 = Mee ny Nollick -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Jedoonee


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
