###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file ti_ER.xml
# The source file version number was 1.45, generated on
# 2007/07/14 23:02:17.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ti_ER;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::ti';

{
    my $date_format_full = "EEEE፡\ dd\ MMMM\ መዓልቲ\ yyyy\ G";
    sub date_format_full { return $date_format_full }
}

{
    my $first_day_of_week = 6;
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "ጥሪ", "ለካቲ", "መጋቢ", "ሚያዝ", "ግንቦ", "ሰነ", "ሓምለ", "ነሓሰ", "መስከ", "ጥቅም", "ሕዳር", "ታሕሳ" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_format_abbreviated() }

{
    my $month_format_wide = [ "ጥሪ", "ለካቲት", "መጋቢት", "ሚያዝያ", "ግንቦት", "ሰነ", "ሓምለ", "ነሓሰ", "መስከረም", "ጥቅምቲ", "ሕዳር", "ታሕሳስ" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }


sub month_stand_alone_wide { $_[0]->month_format_wide() }

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::ti_ER

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'ti_ER' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Tigrinya Eritrea.

=head1 DATA

This locale inherits from the L<DateTime::Locale::ti> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  ሰኑይ
  ሠሉስ
  ረቡዕ
  ኃሙስ
  ዓርቢ
  ቀዳም
  ሰንበት

=head3 Abbreviated (format)

  ሰኑይ
  ሠሉስ
  ረቡዕ
  ኃሙስ
  ዓርቢ
  ቀዳም
  ሰንበ

=head3 Narrow (format)

  ሰ
  ሠ
  ረ
  ኃ
  ዓ
  ቀ
  ሰ

=head3 Wide (stand-alone)

  ሰኑይ
  ሠሉስ
  ረቡዕ
  ኃሙስ
  ዓርቢ
  ቀዳም
  ሰንበት

=head3 Abbreviated (stand-alone)

  ሰኑይ
  ሠሉስ
  ረቡዕ
  ኃሙስ
  ዓርቢ
  ቀዳም
  ሰንበ

=head3 Narrow (stand-alone)

  ሰ
  ሠ
  ረ
  ኃ
  ዓ
  ቀ
  ሰ

=head2 Months

=head3 Wide (format)

  ጥሪ
  ለካቲት
  መጋቢት
  ሚያዝያ
  ግንቦት
  ሰነ
  ሓምለ
  ነሓሰ
  መስከረም
  ጥቅምቲ
  ሕዳር
  ታሕሳስ

=head3 Abbreviated (format)

  ጥሪ
  ለካቲ
  መጋቢ
  ሚያዝ
  ግንቦ
  ሰነ
  ሓምለ
  ነሓሰ
  መስከ
  ጥቅም
  ሕዳር
  ታሕሳ

=head3 Narrow (format)

  ጥሪ
  ለካቲ
  መጋቢ
  ሚያዝ
  ግንቦ
  ሰነ
  ሓምለ
  ነሓሰ
  መስከ
  ጥቅም
  ሕዳር
  ታሕሳ

=head3 Wide (stand-alone)

  ጥሪ
  ለካቲት
  መጋቢት
  ሚያዝያ
  ግንቦት
  ሰነ
  ሓምለ
  ነሓሰ
  መስከረም
  ጥቅምቲ
  ሕዳር
  ታሕሳስ

=head3 Abbreviated (stand-alone)

  ጥሪ
  ለካቲ
  መጋቢ
  ሚያዝ
  ግንቦ
  ሰነ
  ሓምለ
  ነሓሰ
  መስከ
  ጥቅም
  ሕዳር
  ታሕሳ

=head3 Narrow (stand-alone)

  ጃ
  ፌ
  ማ
  ኤ
  ሜ
  ጁ
  ጁ
  ኦ
  ሴ
  ኦ
  ኖ
  ዲ

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  BCE
  CE

=head3 Abbreviated

  ዓ/ዓ
  ዓ/ም

=head3 Narrow

  ዓ/ዓ
  ዓ/ም

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = ሠሉስ፡ 05 ለካቲት መዓልቲ 2008 ዓ/ም
   1995-12-22T09:05:02 = ዓርቢ፡ 22 ታሕሳስ መዓልቲ 1995 ዓ/ም
  -0010-12-22T23:05:02 = ቀዳም፡ 22 ታሕሳስ መዓልቲ -010 ዓ/ዓ

=head3 Long

   2008-02-05T12:30:30 = 05 ለካቲት 2008
   1995-12-22T09:05:02 = 22 ታሕሳስ 1995
  -0010-12-22T23:05:02 = 22 ታሕሳስ -010

=head3 Medium

   2008-02-05T12:30:30 = 05-ለካቲ-2008
   1995-12-22T09:05:02 = 22-ታሕሳ-1995
  -0010-12-22T23:05:02 = 22-ታሕሳ--010

=head3 Short

   2008-02-05T12:30:30 = 05/02/8
   1995-12-22T09:05:02 = 22/12/95
  -0010-12-22T23:05:02 = 22/12/10

=head3 Default

   2008-02-05T12:30:30 = 05-ለካቲ-2008
   1995-12-22T09:05:02 = 22-ታሕሳ-1995
  -0010-12-22T23:05:02 = 22-ታሕሳ--010

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 ድሕር ሰዓት UTC
   1995-12-22T09:05:02 = 9:05:02 ንጉሆ ሰዓተ UTC
  -0010-12-22T23:05:02 = 11:05:02 ድሕር ሰዓት UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 ድሕር ሰዓት UTC
   1995-12-22T09:05:02 = 9:05:02 ንጉሆ ሰዓተ UTC
  -0010-12-22T23:05:02 = 11:05:02 ድሕር ሰዓት UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30 ድሕር ሰዓት
   1995-12-22T09:05:02 = 9:05:02 ንጉሆ ሰዓተ
  -0010-12-22T23:05:02 = 11:05:02 ድሕር ሰዓት

=head3 Short

   2008-02-05T12:30:30 = 12:30 ድሕር ሰዓት
   1995-12-22T09:05:02 = 9:05 ንጉሆ ሰዓተ
  -0010-12-22T23:05:02 = 11:05 ድሕር ሰዓት

=head3 Default

   2008-02-05T12:30:30 = 12:30:30 ድሕር ሰዓት
   1995-12-22T09:05:02 = 9:05:02 ንጉሆ ሰዓተ
  -0010-12-22T23:05:02 = 11:05:02 ድሕር ሰዓት

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = ሠሉስ፡ 05 ለካቲት መዓልቲ 2008 ዓ/ም 12:30:30 ድሕር ሰዓት UTC
   1995-12-22T09:05:02 = ዓርቢ፡ 22 ታሕሳስ መዓልቲ 1995 ዓ/ም 9:05:02 ንጉሆ ሰዓተ UTC
  -0010-12-22T23:05:02 = ቀዳም፡ 22 ታሕሳስ መዓልቲ -010 ዓ/ዓ 11:05:02 ድሕር ሰዓት UTC

=head3 Long

   2008-02-05T12:30:30 = 05 ለካቲት 2008 12:30:30 ድሕር ሰዓት UTC
   1995-12-22T09:05:02 = 22 ታሕሳስ 1995 9:05:02 ንጉሆ ሰዓተ UTC
  -0010-12-22T23:05:02 = 22 ታሕሳስ -010 11:05:02 ድሕር ሰዓት UTC

=head3 Medium

   2008-02-05T12:30:30 = 05-ለካቲ-2008 12:30:30 ድሕር ሰዓት
   1995-12-22T09:05:02 = 22-ታሕሳ-1995 9:05:02 ንጉሆ ሰዓተ
  -0010-12-22T23:05:02 = 22-ታሕሳ--010 11:05:02 ድሕር ሰዓት

=head3 Short

   2008-02-05T12:30:30 = 05/02/8 12:30 ድሕር ሰዓት
   1995-12-22T09:05:02 = 22/12/95 9:05 ንጉሆ ሰዓተ
  -0010-12-22T23:05:02 = 22/12/10 11:05 ድሕር ሰዓት

=head3 Default

   2008-02-05T12:30:30 = 05-ለካቲ-2008 12:30:30 ድሕር ሰዓት
   1995-12-22T09:05:02 = 22-ታሕሳ-1995 9:05:02 ንጉሆ ሰዓተ
  -0010-12-22T23:05:02 = 22-ታሕሳ--010 11:05:02 ድሕር ሰዓት

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = ሠሉስ 5
   1995-12-22T09:05:02 = ዓርቢ 22
  -0010-12-22T23:05:02 = ቀዳም 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = ሠሉስ ለካቲ 5
   1995-12-22T09:05:02 = ዓርቢ ታሕሳ 22
  -0010-12-22T23:05:02 = ቀዳም ታሕሳ 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = ለካቲት 5
   1995-12-22T09:05:02 = ታሕሳስ 22
  -0010-12-22T23:05:02 = ታሕሳስ 22

=head3 MMMMdd (dd MMMM)

   2008-02-05T12:30:30 = 05 ለካቲት
   1995-12-22T09:05:02 = 22 ታሕሳስ
  -0010-12-22T23:05:02 = 22 ታሕሳስ

=head3 MMdd (dd/MM)

   2008-02-05T12:30:30 = 05/02
   1995-12-22T09:05:02 = 22/12
  -0010-12-22T23:05:02 = 22/12

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (MM/yy)

   2008-02-05T12:30:30 = 02/8
   1995-12-22T09:05:02 = 12/95
  -0010-12-22T23:05:02 = 12/10

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 ለካቲ
   1995-12-22T09:05:02 = 95 ታሕሳ
  -0010-12-22T23:05:02 = 10 ታሕሳ

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head3 yyyyMMMM (MMMM yyyy)

   2008-02-05T12:30:30 = ለካቲት 2008
   1995-12-22T09:05:02 = ታሕሳስ 1995
  -0010-12-22T23:05:02 = ታሕሳስ -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

No

=head3 Local first day of the week

ቀዳም


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
