###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file sr_Latn.xml
# The source file version number was 1.65, generated on
# 2007/07/21 21:12:28.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sr_Latn;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::sr';

{
    my $day_format_abbreviated = [ "pon", "uto", "sre", "čet", "pet", "sub", "ned" ];
    sub day_format_abbreviated { return $day_format_abbreviated }
}

sub day_format_narrow { $_[0]->day_stand_alone_narrow() }

{
    my $day_format_wide = [ "ponedeljak", "utorak", "sreda", "četvrtak", "petak", "subota", "nedelja" ];
    sub day_format_wide { return $day_format_wide }
}

sub day_stand_alone_abbreviated { $_[0]->day_format_abbreviated() }

{
    my $day_stand_alone_narrow = [ "p", "u", "s", "č", "p", "s", "n" ];
    sub day_stand_alone_narrow { return $day_stand_alone_narrow }
}

sub day_stand_alone_wide { $_[0]->day_format_wide() }

{
    my $era_abbreviated = [ "p\.\ n\.\ e\.", "n\.\ e" ];
    sub era_abbreviated { return $era_abbreviated }
}
{
    my $era_narrow = [ "p\.n\.e\.", "n\.\ e\." ];
    sub era_narrow { return $era_narrow }
}
{
    my $era_wide = [ "Pre\ nove\ ere", "Nove\ ere" ];
    sub era_wide { return $era_wide }
}
{
    my $first_day_of_week = 1;
    sub first_day_of_week { return $first_day_of_week }
}

{
    my $month_format_abbreviated = [ "jan", "feb", "mar", "apr", "maj", "jun", "jul", "avg", "sep", "okt", "nov", "dec" ];
    sub month_format_abbreviated { return $month_format_abbreviated }
}

sub month_format_narrow { $_[0]->month_stand_alone_narrow() }

{
    my $month_format_wide = [ "januar", "februar", "mart", "april", "maj", "jun", "jul", "avgust", "septembar", "oktobar", "novembar", "decembar" ];
    sub month_format_wide { return $month_format_wide }
}

sub month_stand_alone_abbreviated { $_[0]->month_format_abbreviated() }

{
    my $month_stand_alone_narrow = [ "j", "f", "m", "a", "m", "j", "j", "a", "s", "o", "n", "d" ];
    sub month_stand_alone_narrow { return $month_stand_alone_narrow }
}

sub month_stand_alone_wide { $_[0]->month_format_wide() }

{
    my $quarter_format_abbreviated = [ "K1", "K2", "K3", "K4" ];
    sub quarter_format_abbreviated { return $quarter_format_abbreviated }
}
{
    my $quarter_format_wide = [ "Prvo\ tromesečje", "Drugo\ tromesečje", "Treće\ tromesečje", "Četvrto\ tromesečje" ];
    sub quarter_format_wide { return $quarter_format_wide }
}

sub quarter_stand_alone_abbreviated { $_[0]->quarter_format_abbreviated() }

{
    my $quarter_stand_alone_wide = [ "Prvo\ tromesečje", "Drugo\ tromesečje", "Treće\ tromesečje", "Četvrto\ tromesečje" ];
    sub quarter_stand_alone_wide { return $quarter_stand_alone_wide }
}
{
    my $time_format_full = "HH\ \'časova\'\,\ mm\ \'minuta\'\,\ ss\ \'sekundi\'\ vvvv";
    sub time_format_full { return $time_format_full }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::sr_Latn

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'sr_Latn' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Serbian Latin.

=head1 DATA

This locale inherits from the L<DateTime::Locale::sr> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  ponedeljak
  utorak
  sreda
  četvrtak
  petak
  subota
  nedelja

=head3 Abbreviated (format)

  pon
  uto
  sre
  čet
  pet
  sub
  ned

=head3 Narrow (format)

  p
  u
  s
  č
  p
  s
  n

=head3 Wide (stand-alone)

  ponedeljak
  utorak
  sreda
  četvrtak
  petak
  subota
  nedelja

=head3 Abbreviated (stand-alone)

  pon
  uto
  sre
  čet
  pet
  sub
  ned

=head3 Narrow (stand-alone)

  p
  u
  s
  č
  p
  s
  n

=head2 Months

=head3 Wide (format)

  januar
  februar
  mart
  april
  maj
  jun
  jul
  avgust
  septembar
  oktobar
  novembar
  decembar

=head3 Abbreviated (format)

  jan
  feb
  mar
  apr
  maj
  jun
  jul
  avg
  sep
  okt
  nov
  dec

=head3 Narrow (format)

  j
  f
  m
  a
  m
  j
  j
  a
  s
  o
  n
  d

=head3 Wide (stand-alone)

  januar
  februar
  mart
  april
  maj
  jun
  jul
  avgust
  septembar
  oktobar
  novembar
  decembar

=head3 Abbreviated (stand-alone)

  jan
  feb
  mar
  apr
  maj
  jun
  jul
  avg
  sep
  okt
  nov
  dec

=head3 Narrow (stand-alone)

  j
  f
  m
  a
  m
  j
  j
  a
  s
  o
  n
  d

=head2 Quarters

=head3 Wide (format)

  Prvo tromesečje
  Drugo tromesečje
  Treće tromesečje
  Četvrto tromesečje

=head3 Abbreviated (format)

  K1
  K2
  K3
  K4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Prvo tromesečje
  Drugo tromesečje
  Treće tromesečje
  Četvrto tromesečje

=head3 Abbreviated (stand-alone)

  K1
  K2
  K3
  K4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Pre nove ere
  Nove ere

=head3 Abbreviated

  p. n. e.
  n. e

=head3 Narrow

  p.n.e.
  n. e.

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = utorak, 05. februar 2008.
   1995-12-22T09:05:02 = petak, 22. decembar 1995.
  -0010-12-22T23:05:02 = subota, 22. decembar -010.

=head3 Long

   2008-02-05T12:30:30 = 05. februar 2008.
   1995-12-22T09:05:02 = 22. decembar 1995.
  -0010-12-22T23:05:02 = 22. decembar -010.

=head3 Medium

   2008-02-05T12:30:30 = 05.02.2008.
   1995-12-22T09:05:02 = 22.12.1995.
  -0010-12-22T23:05:02 = 22.12.-010.

=head3 Short

   2008-02-05T12:30:30 = 5.2.8.
   1995-12-22T09:05:02 = 22.12.95.
  -0010-12-22T23:05:02 = 22.12.10.

=head3 Default

   2008-02-05T12:30:30 = 05.02.2008.
   1995-12-22T09:05:02 = 22.12.1995.
  -0010-12-22T23:05:02 = 22.12.-010.

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12 časova, 30 minuta, 30 sekundi UTC
   1995-12-22T09:05:02 = 09 časova, 05 minuta, 02 sekundi UTC
  -0010-12-22T23:05:02 = 23 časova, 05 minuta, 02 sekundi UTC

=head3 Long

   2008-02-05T12:30:30 = 12.30.30 UTC
   1995-12-22T09:05:02 = 09.05.02 UTC
  -0010-12-22T23:05:02 = 23.05.02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-12-22T23:05:02 = 23.05.02

=head3 Short

   2008-02-05T12:30:30 = 12.30
   1995-12-22T09:05:02 = 09.05
  -0010-12-22T23:05:02 = 23.05

=head3 Default

   2008-02-05T12:30:30 = 12.30.30
   1995-12-22T09:05:02 = 09.05.02
  -0010-12-22T23:05:02 = 23.05.02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = utorak, 05. februar 2008. 12 časova, 30 minuta, 30 sekundi UTC
   1995-12-22T09:05:02 = petak, 22. decembar 1995. 09 časova, 05 minuta, 02 sekundi UTC
  -0010-12-22T23:05:02 = subota, 22. decembar -010. 23 časova, 05 minuta, 02 sekundi UTC

=head3 Long

   2008-02-05T12:30:30 = 05. februar 2008. 12.30.30 UTC
   1995-12-22T09:05:02 = 22. decembar 1995. 09.05.02 UTC
  -0010-12-22T23:05:02 = 22. decembar -010. 23.05.02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 05.02.2008. 12.30.30
   1995-12-22T09:05:02 = 22.12.1995. 09.05.02
  -0010-12-22T23:05:02 = 22.12.-010. 23.05.02

=head3 Short

   2008-02-05T12:30:30 = 5.2.8. 12.30
   1995-12-22T09:05:02 = 22.12.95. 09.05
  -0010-12-22T23:05:02 = 22.12.10. 23.05

=head3 Default

   2008-02-05T12:30:30 = 05.02.2008. 12.30.30
   1995-12-22T09:05:02 = 22.12.1995. 09.05.02
  -0010-12-22T23:05:02 = 22.12.-010. 23.05.02

=head2 Available Formats

=head3 Ed (E d.)

   2008-02-05T12:30:30 = uto 5.
   1995-12-22T09:05:02 = pet 22.
  -0010-12-22T23:05:02 = sub 22.

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E d. MMM)

   2008-02-05T12:30:30 = uto 5. feb
   1995-12-22T09:05:02 = pet 22. dec
  -0010-12-22T23:05:02 = sub 22. dec

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = februar 5
   1995-12-22T09:05:02 = decembar 22
  -0010-12-22T23:05:02 = decembar 22

=head3 MMMMdd (dd. MMMM)

   2008-02-05T12:30:30 = 05. februar
   1995-12-22T09:05:02 = 22. decembar
  -0010-12-22T23:05:02 = 22. decembar

=head3 MMMdd (dd.MMM)

   2008-02-05T12:30:30 = 05.feb
   1995-12-22T09:05:02 = 22.dec
  -0010-12-22T23:05:02 = 22.dec

=head3 MMdd (MM-dd)

   2008-02-05T12:30:30 = 02-05
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 hhmm (hh:mm a)

   2008-02-05T12:30:30 = 12:30 PM
   1995-12-22T09:05:02 = 09:05 AM
  -0010-12-22T23:05:02 = 11:05 PM

=head3 hhmmss (hh:mm:ss a)

   2008-02-05T12:30:30 = 12:30:30 PM
   1995-12-22T09:05:02 = 09:05:02 AM
  -0010-12-22T23:05:02 = 11:05:02 PM

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (MM.yy)

   2008-02-05T12:30:30 = 02.8
   1995-12-22T09:05:02 = 12.95
  -0010-12-22T23:05:02 = 12.10

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 feb
   1995-12-22T09:05:02 = 95 dec
  -0010-12-22T23:05:02 = 10 dec

=head3 yyMMMd (d. MMM yy.)

   2008-02-05T12:30:30 = 5. feb 8.
   1995-12-22T09:05:02 = 22. dec 95.
  -0010-12-22T23:05:02 = 22. dec 10.

=head3 yyMMdd (dd.MM.yy)

   2008-02-05T12:30:30 = 05.02.8
   1995-12-22T09:05:02 = 22.12.95
  -0010-12-22T23:05:02 = 22.12.10

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyQQQQ (QQQQ yy)

   2008-02-05T12:30:30 = Prvo tromesečje 8
   1995-12-22T09:05:02 = Četvrto tromesečje 95
  -0010-12-22T23:05:02 = Četvrto tromesečje 10

=head3 yyyy (yyyy.)

   2008-02-05T12:30:30 = 2008.
   1995-12-22T09:05:02 = 1995.
  -0010-12-22T23:05:02 = -010.

=head3 yyyyMM (yyyy-MM)

   2008-02-05T12:30:30 = 2008-02
   1995-12-22T09:05:02 = 1995-12
  -0010-12-22T23:05:02 = -010-12

=head3 yyyyMMMM (MMMM yyyy.)

   2008-02-05T12:30:30 = februar 2008.
   1995-12-22T09:05:02 = decembar 1995.
  -0010-12-22T23:05:02 = decembar -010.

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

ponedeljak


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
