###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file kam_KE.xml
# The source file version number was 1.12, generated on
# 2007/07/19 22:31:39.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::kam_KE;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::kam';

{
    my $first_day_of_week = 6;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::kam_KE

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'kam_KE' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Kamba Kenya.

=head1 DATA

This locale inherits from the L<DateTime::Locale::kam> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Jumatatu
  Jumanne
  Jumatano
  Alamisi
  Ijumaa
  Jumamosi
  Jumapili

=head3 Abbreviated (format)

  Jtt
  Jnn
  Jtn
  Alh
  Ijm
  Jms
  Jpl

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  Jumatatu
  Jumanne
  Jumatano
  Alamisi
  Ijumaa
  Jumamosi
  Jumapili

=head3 Abbreviated (stand-alone)

  Jtt
  Jnn
  Jtn
  Alh
  Ijm
  Jms
  Jpl

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  Mwei wa mbee
  Mwei wa keli
  Mwei wa katatu
  Mwei wa kanne
  Mwei wa katano
  Mwei wa thanthatu
  Mwei wa muonza
  Mwei wa nyanya
  Mwei wa kenda
  Mwei wa ikumi
  Mwei wa ikumi na imwe
  Mwei wa ikumi na ili

=head3 Abbreviated (format)

  Mwei wa mbee
  Mwei wa keli
  Mwei wa katatu
  Mwei wa kanne
  Mwei wa katano
  Mwei wa thanthatu
  Mwei wa muonza
  Mwei wa nyanya
  Mwei wa kenda
  Mwei wa ikumi
  Mwei wa ikumi na imwe
  Mwei wa ikumi na ili

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  Mwei wa mbee
  Mwei wa keli
  Mwei wa katatu
  Mwei wa kanne
  Mwei wa katano
  Mwei wa thanthatu
  Mwei wa muonza
  Mwei wa nyanya
  Mwei wa kenda
  Mwei wa ikumi
  Mwei wa ikumi na imwe
  Mwei wa ikumi na ili

=head3 Abbreviated (stand-alone)

  Mwei wa mbee
  Mwei wa keli
  Mwei wa katatu
  Mwei wa kanne
  Mwei wa katano
  Mwei wa thanthatu
  Mwei wa muonza
  Mwei wa nyanya
  Mwei wa kenda
  Mwei wa ikumi
  Mwei wa ikumi na imwe
  Mwei wa ikumi na ili

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  mbee wa yesu
  IY

=head3 Abbreviated

  MY
  IY

=head3 Narrow

  MY
  IY

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = Jumanne, 2008 Mwei wa keli 05
   1995-12-22T09:05:02 = Ijumaa, 1995 Mwei wa ikumi na ili 22
  -0010-12-22T23:05:02 = Jumamosi, -010 Mwei wa ikumi na ili 22

=head3 Long

   2008-02-05T12:30:30 = 2008 Mwei wa keli 5
   1995-12-22T09:05:02 = 1995 Mwei wa ikumi na ili 22
  -0010-12-22T23:05:02 = -010 Mwei wa ikumi na ili 22

=head3 Medium

   2008-02-05T12:30:30 = 2008 Mwei wa keli 5
   1995-12-22T09:05:02 = 1995 Mwei wa ikumi na ili 22
  -0010-12-22T23:05:02 = -010 Mwei wa ikumi na ili 22

=head3 Short

   2008-02-05T12:30:30 = 8/02/05
   1995-12-22T09:05:02 = 95/12/22
  -0010-12-22T23:05:02 = 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 2008 Mwei wa keli 5
   1995-12-22T09:05:02 = 1995 Mwei wa ikumi na ili 22
  -0010-12-22T23:05:02 = -010 Mwei wa ikumi na ili 22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = Jumanne, 2008 Mwei wa keli 05 12:30:30 UTC
   1995-12-22T09:05:02 = Ijumaa, 1995 Mwei wa ikumi na ili 22 09:05:02 UTC
  -0010-12-22T23:05:02 = Jumamosi, -010 Mwei wa ikumi na ili 22 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008 Mwei wa keli 5 12:30:30 UTC
   1995-12-22T09:05:02 = 1995 Mwei wa ikumi na ili 22 09:05:02 UTC
  -0010-12-22T23:05:02 = -010 Mwei wa ikumi na ili 22 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008 Mwei wa keli 5 12:30:30
   1995-12-22T09:05:02 = 1995 Mwei wa ikumi na ili 22 09:05:02
  -0010-12-22T23:05:02 = -010 Mwei wa ikumi na ili 22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8/02/05 12:30
   1995-12-22T09:05:02 = 95/12/22 09:05
  -0010-12-22T23:05:02 = 10/12/22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008 Mwei wa keli 5 12:30:30
   1995-12-22T09:05:02 = 1995 Mwei wa ikumi na ili 22 09:05:02
  -0010-12-22T23:05:02 = -010 Mwei wa ikumi na ili 22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = Jnn 5
   1995-12-22T09:05:02 = Ijm 22
  -0010-12-22T23:05:02 = Jms 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = Jnn Mwei wa keli 5
   1995-12-22T09:05:02 = Ijm Mwei wa ikumi na ili 22
  -0010-12-22T23:05:02 = Jms Mwei wa ikumi na ili 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = Mwei wa keli 5
   1995-12-22T09:05:02 = Mwei wa ikumi na ili 22
  -0010-12-22T23:05:02 = Mwei wa ikumi na ili 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 Mwei wa keli
   1995-12-22T09:05:02 = 95 Mwei wa ikumi na ili
  -0010-12-22T23:05:02 = 10 Mwei wa ikumi na ili

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Jumamosi


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
