###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite locale
# generator (0.05).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate-from-cldr.
#
# This file as generated from the CLDR XML locale data.  See the
# LICENSE.cldr file included in this distribution for license details.
#
# This file was generated from the source file cch_NG.xml
# The source file version number was 1.13, generated on
# 2007/07/19 22:31:38.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::cch_NG;

use strict;
use warnings;
use utf8;

use base 'DateTime::Locale::cch';

{
    my $first_day_of_week = 7;
    sub first_day_of_week { return $first_day_of_week }
}

1;

__END__


=pod

=encoding utf8

=head1 NAME

DateTime::Locale::cch_NG

=head1 SYNOPSIS

  use DateTime;

  my $dt = DateTime->now( locale => 'cch_NG' );
  print $dt->month_name();

=head1 DESCRIPTION

This is the DateTime locale package for Atsam Nigeria.

=head1 DATA

This locale inherits from the L<DateTime::Locale::cch> locale.

It contains the following data.

=head2 Days

=head3 Wide (format)

  Wai Tunga
  Toki Gitung
  Tsam Kasuwa
  Wai Na Nas
  Wai Na Tiyon
  Wai Na Chirim
  Wai Yoka Bawai

=head3 Abbreviated (format)

  Tung
  T. Tung
  Tsan
  Nas
  Nat
  Chir
  Yok

=head3 Narrow (format)

  2
  3
  4
  5
  6
  7
  1

=head3 Wide (stand-alone)

  Wai Tunga
  Toki Gitung
  Tsam Kasuwa
  Wai Na Nas
  Wai Na Tiyon
  Wai Na Chirim
  Wai Yoka Bawai

=head3 Abbreviated (stand-alone)

  Tung
  T. Tung
  Tsan
  Nas
  Nat
  Chir
  Yok

=head3 Narrow (stand-alone)

  2
  3
  4
  5
  6
  7
  1

=head2 Months

=head3 Wide (format)

  Pen Dyon
  Pen Ba'a
  Pen Atat
  Pen Anas
  Pen Atyon
  Pen Achirim
  Pen Atariba
  Pen Awurr
  Pen Shadon
  Pen Shakur
  Pen Kur Naba
  Pen Kur Natat

=head3 Abbreviated (format)

  Dyon
  Baa
  Atat
  Anas
  Atyo
  Achi
  Atar
  Awur
  Shad
  Shak
  Naba
  Nata

=head3 Narrow (format)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head3 Wide (stand-alone)

  Pen Dyon
  Pen Ba'a
  Pen Atat
  Pen Anas
  Pen Atyon
  Pen Achirim
  Pen Atariba
  Pen Awurr
  Pen Shadon
  Pen Shakur
  Pen Kur Naba
  Pen Kur Natat

=head3 Abbreviated (stand-alone)

  Dyon
  Baa
  Atat
  Anas
  Atyo
  Achi
  Atar
  Awur
  Shad
  Shak
  Naba
  Nata

=head3 Narrow (stand-alone)

  1
  2
  3
  4
  5
  6
  7
  8
  9
  10
  11
  12

=head2 Quarters

=head3 Wide (format)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (format)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (format)

  1
  2
  3
  4

=head3 Wide (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Abbreviated (stand-alone)

  Q1
  Q2
  Q3
  Q4

=head3 Narrow (stand-alone)

  1
  2
  3
  4

=head2 Eras

=head3 Wide

  Gabanin Miladi
  Miladi

=head3 Abbreviated

  GM
  M

=head3 Narrow

  GM
  M

=head2 Date Formats

=head3 Full

   2008-02-05T12:30:30 = Toki Gitung, 2008 Pen Ba'a 05
   1995-12-22T09:05:02 = Wai Na Tiyon, 1995 Pen Kur Natat 22
  -0010-12-22T23:05:02 = Wai Na Chirim, -010 Pen Kur Natat 22

=head3 Long

   2008-02-05T12:30:30 = 2008 Pen Ba'a 5
   1995-12-22T09:05:02 = 1995 Pen Kur Natat 22
  -0010-12-22T23:05:02 = -010 Pen Kur Natat 22

=head3 Medium

   2008-02-05T12:30:30 = 2008 Baa 5
   1995-12-22T09:05:02 = 1995 Nata 22
  -0010-12-22T23:05:02 = -010 Nata 22

=head3 Short

   2008-02-05T12:30:30 = 8/02/05
   1995-12-22T09:05:02 = 95/12/22
  -0010-12-22T23:05:02 = 10/12/22

=head3 Default

   2008-02-05T12:30:30 = 2008 Baa 5
   1995-12-22T09:05:02 = 1995 Nata 22
  -0010-12-22T23:05:02 = -010 Nata 22

=head2 Time Formats

=head3 Full

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 12:30:30 UTC
   1995-12-22T09:05:02 = 09:05:02 UTC
  -0010-12-22T23:05:02 = 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 Default

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head2 Datetime Formats

=head3 Full

   2008-02-05T12:30:30 = Toki Gitung, 2008 Pen Ba'a 05 12:30:30 UTC
   1995-12-22T09:05:02 = Wai Na Tiyon, 1995 Pen Kur Natat 22 09:05:02 UTC
  -0010-12-22T23:05:02 = Wai Na Chirim, -010 Pen Kur Natat 22 23:05:02 UTC

=head3 Long

   2008-02-05T12:30:30 = 2008 Pen Ba'a 5 12:30:30 UTC
   1995-12-22T09:05:02 = 1995 Pen Kur Natat 22 09:05:02 UTC
  -0010-12-22T23:05:02 = -010 Pen Kur Natat 22 23:05:02 UTC

=head3 Medium

   2008-02-05T12:30:30 = 2008 Baa 5 12:30:30
   1995-12-22T09:05:02 = 1995 Nata 22 09:05:02
  -0010-12-22T23:05:02 = -010 Nata 22 23:05:02

=head3 Short

   2008-02-05T12:30:30 = 8/02/05 12:30
   1995-12-22T09:05:02 = 95/12/22 09:05
  -0010-12-22T23:05:02 = 10/12/22 23:05

=head3 Default

   2008-02-05T12:30:30 = 2008 Baa 5 12:30:30
   1995-12-22T09:05:02 = 1995 Nata 22 09:05:02
  -0010-12-22T23:05:02 = -010 Nata 22 23:05:02

=head2 Available Formats

=head3 Ed (E d)

   2008-02-05T12:30:30 = T. Tung 5
   1995-12-22T09:05:02 = Nat 22
  -0010-12-22T23:05:02 = Chir 22

=head3 H (H)

   2008-02-05T12:30:30 = 12
   1995-12-22T09:05:02 = 9
  -0010-12-22T23:05:02 = 23

=head3 HHmm (HH:mm)

   2008-02-05T12:30:30 = 12:30
   1995-12-22T09:05:02 = 09:05
  -0010-12-22T23:05:02 = 23:05

=head3 HHmmss (HH:mm:ss)

   2008-02-05T12:30:30 = 12:30:30
   1995-12-22T09:05:02 = 09:05:02
  -0010-12-22T23:05:02 = 23:05:02

=head3 MMMEd (E MMM d)

   2008-02-05T12:30:30 = T. Tung Baa 5
   1995-12-22T09:05:02 = Nat Nata 22
  -0010-12-22T23:05:02 = Chir Nata 22

=head3 MMMMd (MMMM d)

   2008-02-05T12:30:30 = Pen Ba'a 5
   1995-12-22T09:05:02 = Pen Kur Natat 22
  -0010-12-22T23:05:02 = Pen Kur Natat 22

=head3 Md (M-d)

   2008-02-05T12:30:30 = 2-5
   1995-12-22T09:05:02 = 12-22
  -0010-12-22T23:05:02 = 12-22

=head3 mmss (mm:ss)

   2008-02-05T12:30:30 = 30:30
   1995-12-22T09:05:02 = 05:02
  -0010-12-22T23:05:02 = 05:02

=head3 yyMM (yy-MM)

   2008-02-05T12:30:30 = 8-02
   1995-12-22T09:05:02 = 95-12
  -0010-12-22T23:05:02 = 10-12

=head3 yyMMM (yy MMM)

   2008-02-05T12:30:30 = 8 Baa
   1995-12-22T09:05:02 = 95 Nata
  -0010-12-22T23:05:02 = 10 Nata

=head3 yyQ (Q yy)

   2008-02-05T12:30:30 = 1 8
   1995-12-22T09:05:02 = 4 95
  -0010-12-22T23:05:02 = 4 10

=head3 yyyy (yyyy)

   2008-02-05T12:30:30 = 2008
   1995-12-22T09:05:02 = 1995
  -0010-12-22T23:05:02 = -010

=head2 Miscellaneous

=head3 Prefers 24 hour time?

Yes

=head3 Local first day of the week

Wai Yoka Bawai


=head1 SUPPORT

See L<DateTime::Locale>.

=head1 AUTHOR

Dave Rolsky <autarch@urth.org>

=head1 COPYRIGHT

Copyright (c) 2008 David Rolsky. All rights reserved. This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

This module was generated from data provided by the CLDR project, see
the LICENSE.cldr in this distribution for details on the CLDR data's
license.

=cut
